<?php
session_start();
require '../config.php';

// // 权限验证（仅管理员和采购）
// if (!isset($_SESSION['user_id']) || ($_SESSION['role'] !== 'admin' && $_SESSION['role'] !== 'store_manager')) {
//     header("Location: login.php");
//     exit;
// }

// 获取热销商品数据
$hot_products = $pdo->query("
    SELECT 
        p.product_id,
        p.sku,
        p.brand,
        p.model,
        SUM(oi.quantity) AS total_sold,
        SUM(oi.quantity * oi.unit_price) AS total_sales,
        COUNT(DISTINCT oi.order_id) AS order_count
    FROM order_item oi
    JOIN products p USING(product_id)
    JOIN sales_order so ON oi.order_id = so.order_id
    WHERE so.created_at >= DATE_SUB(NOW(), INTERVAL 30 DAY)
    GROUP BY p.product_id
    ORDER BY total_sold DESC
    LIMIT 10
")->fetchAll();

?>
<!DOCTYPE html>
<html>

<head>
    <title>热销商品分析</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>热销商品TOP10（近30天）</h2>

        <div class="table-container">
            <table>
                <thead>
                    <tr>
                        <th>商品编码</th>
                        <th>品牌型号</th>
                        <th>销售总量</th>
                        <th>总销售额</th>
                        <th>订单数量</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($hot_products as $product): ?>
                        <tr>
                            <td><?= $product['sku'] ?></td>
                            <td><?= htmlspecialchars($product['brand'] . ' ' . $product['model']) ?></td>
                            <td><?= $product['total_sold'] ?>件</td>
                            <td>¥<?= number_format($product['total_sales'], 2) ?></td>
                            <td><?= $product['order_count'] ?>单</td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>