<?php
session_start();
require '../config.php';

// // 权限验证（仅管理员和采购）
// if (!isset($_SESSION['user_id']) || ($_SESSION['role'] !== 'admin' && $_SESSION['role'] !== 'store_manager')) {
//     header("Location: login.php");
//     exit;
// }

// 获取库存数据
$inventory_data = $pdo->query("
    SELECT 
        p.sku,
        p.brand,
        p.model,
        SUM(i.quantity) AS stock_quantity,
        SUM(oi.quantity) AS sold_quantity,
        DATEDIFF(NOW(), MAX(i.last_sync)) AS days_since_update,
        CASE 
            WHEN SUM(oi.quantity) = 0 THEN 9999
            ELSE SUM(i.quantity) / SUM(oi.quantity)
        END AS turnover_ratio
    FROM inventory i
    LEFT JOIN products p USING(product_id)
    LEFT JOIN order_item oi USING(product_id)
    GROUP BY p.product_id
    HAVING stock_quantity > 0
    ORDER BY turnover_ratio DESC
")->fetchAll();

?>
<!DOCTYPE html>
<html>

<head>
    <title>库存周转分析</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>库存周转率分析</h2>

        <div class="table-container">
            <table>
                <thead>
                    <tr>
                        <th>商品编码</th>
                        <th>库存数量</th>
                        <th>销售数量</th>
                        <th>周转率</th>
                        <th>库存天数</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($inventory_data as $item): ?>
                        <tr class="<?= $item['turnover_ratio'] > 6 ? 'warning-row' : '' ?>">
                            <td><?= $item['sku'] ?></td>
                            <td><?= $item['stock_quantity'] ?></td>
                            <td><?= $item['sold_quantity'] ?? 0 ?></td>
                            <td><?= number_format($item['turnover_ratio'], 1) ?> 倍</td>
                            <td><?= $item['days_since_update'] ?> 天</td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>