<?php
session_start();
require '../config.php';

// // 权限验证（仅管理员和财务）
// if (!isset($_SESSION['user_id']) || ($_SESSION['role'] !== 'admin' && $_SESSION['role'] !== 'finance')) {
//     header("Location: login.php");
//     exit;
// }

// 获取趋势数据
$trend_data = $pdo->query("
    SELECT 
        DATE_FORMAT(so.created_at, '%Y-%m') AS month,
        SUM(so.total_amount) AS total_sales,
        COUNT(*) AS order_count,
        SUM(oi.quantity) AS total_quantity
    FROM sales_order so
    JOIN order_item oi USING(order_id)
    WHERE so.created_at >= DATE_SUB(NOW(), INTERVAL 1 YEAR)
    GROUP BY month
    ORDER BY month DESC
")->fetchAll();

?>
<!DOCTYPE html>
<html>

<head>
    <title>销售趋势分析</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>月度销售趋势</h2>

        <div class="chart-container">
            <canvas id="trendChart" width="800" height="400"></canvas>
        </div>

        <div class="table-container">
            <table>
                <thead>
                    <tr>
                        <th>月份</th>
                        <th>销售额</th>
                        <th>订单数</th>
                        <th>销售数量</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($trend_data as $row): ?>
                        <tr>
                            <td><?= $row['month'] ?></td>
                            <td>¥<?= number_format($row['total_sales'], 2) ?></td>
                            <td><?= $row['order_count'] ?></td>
                            <td><?= $row['total_quantity'] ?>件</td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script>
        const ctx = document.getElementById('trendChart').getContext('2d');
        new Chart(ctx, {
            type: 'line',
            data: {
                labels: <?= json_encode(array_column($trend_data, 'month')) ?>,
                datasets: [{
                    label: '月销售额',
                    data: <?= json_encode(array_column($trend_data, 'total_sales')) ?>,
                    borderColor: '#3498db',
                    tension: 0.1
                }]
            },
            options: {
                scales: {
                    y: {
                        beginAtZero: true,
                        ticks: {
                            callback: function(value) {
                                return '¥' + value.toLocaleString();
                            }
                        }
                    }
                }
            }
        });
    </script>
</body>

</html>