<?php
session_start();
require '../config.php';

// // 权限验证（仅管理员和店长可操作）
// if (!isset($_SESSION['user_id']) || ($_SESSION['role'] !== 'admin' && $_SESSION['role'] !== 'store_manager')) {
//     header("Location: login.php");
//     exit;
// }

// 处理所有会员操作
$error = '';
$success = '';

// 添加会员
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_member'])) {
    $customer_name = trim($_POST['customer_name']);
    $phone = trim($_POST['phone']);
    $membership_level = (int)$_POST['membership_level'];
    $credit_limit = (float)$_POST['credit_limit'];

    try {
        $stmt = $pdo->prepare("
            INSERT INTO customer 
            (customer_name, phone, customer_type, membership_level, credit_limit)
            VALUES (?, ?, '会员', ?, ?)
        ");
        $stmt->execute([$customer_name, $phone, $membership_level, $credit_limit]);
        $success = "会员添加成功！";
    } catch (PDOException $e) {
        $error = "添加失败：" . $e->getMessage();
    }
}

// 更新会员信息
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_member'])) {
    $customer_id = (int)$_POST['customer_id'];
    $new_level = (int)$_POST['new_level'];
    $new_points = (int)$_POST['new_points'];

    try {
        $stmt = $pdo->prepare("
            UPDATE customer 
            SET membership_level = ?, accumulated_points = ?
            WHERE customer_id = ?
        ");
        $stmt->execute([$new_level, $new_points, $customer_id]);
        $success = "会员信息更新成功！";
    } catch (PDOException $e) {
        $error = "更新失败：" . $e->getMessage();
    }
}

// 删除会员
if (isset($_GET['delete_member'])) {
    $customer_id = (int)$_GET['delete_member'];
    try {
        $stmt = $pdo->prepare("DELETE FROM customer WHERE customer_id = ?");
        $stmt->execute([$customer_id]);
        $success = "会员删除成功！";
    } catch (PDOException $e) {
        $error = "删除失败：" . $e->getMessage();
    }
}

// 获取所有会员
$members = $pdo->query("
    SELECT * FROM customer 
    WHERE customer_type = '会员'
    ORDER BY customer_id DESC
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>会员管理</title>
<link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h1>会员管理</h1>

        <!-- 操作提示 -->
        <?php if ($success): ?>
            <div class="alert alert-success"><?= $success ?></div>
        <?php elseif ($error): ?>
            <div class="alert alert-error"><?= $error ?></div>
        <?php endif; ?>

        <!-- 添加会员表单 -->
        <div class="form-section">
            <h2>添加新会员</h2>
            <form method="POST">
                <div class="form-group">
                    <label>会员姓名</label>
                    <input type="text" name="customer_name" required>
                </div>
                <div class="form-group">
                    <label>手机号</label>
                    <input type="text" name="phone" required>
                </div>
                <div class="form-group">
                    <label>会员等级</label>
                    <select name="membership_level" required>
                        <option value="1">等级 1</option>
                        <option value="2">等级 2</option>
                        <option value="3">等级 3</option>
                    </select>
                </div>
                <div class="form-group">
                    <label>初始信用额度</label>
                    <input type="number" name="credit_limit" step="0.01" required>
                </div>
                <button type="submit" name="add_member" class="btn">立即添加</button>
            </form>
        </div>

        <!-- 会员列表及管理 -->
        <div class="form-section">
            <h2>会员列表</h2>
            <table class="member-table">
                <thead>
                    <tr>
                        <th>姓名</th>
                        <th>手机号</th>
                        <th>等级</th>
                        <th>积分</th>
                        <th>信用额度</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($members as $member): ?>
                        <tr>
                            <td><?= htmlspecialchars($member['customer_name']) ?></td>
                            <td><?= htmlspecialchars($member['phone']) ?></td>
                            <td>
                                <form method="POST" style="display:inline;">
                                    <input type="hidden" name="customer_id" value="<?= $member['customer_id'] ?>">
                                    <select name="new_level" onchange="this.form.submit()">
                                        <option value="1" <?= $member['membership_level'] == 1 ? 'selected' : '' ?>>等级 1</option>
                                        <option value="2" <?= $member['membership_level'] == 2 ? 'selected' : '' ?>>等级 2</option>
                                        <option value="3" <?= $member['membership_level'] == 3 ? 'selected' : '' ?>>等级 3</option>
                                    </select>
                                    <input type="hidden" name="update_member">
                                </form>
                            </td>
                            <td>
                                <form method="POST" style="display:inline;">
                                    <input type="hidden" name="customer_id" value="<?= $member['customer_id'] ?>">
                                    <input type="number" name="new_points" value="<?= $member['accumulated_points'] ?>"
                                        style="width:80px;" onchange="this.form.submit()">
                                    <input type="hidden" name="update_member">
                                </form>
                            </td>
                            <td>¥<?= number_format($member['credit_limit'], 2) ?></td>
                            <td>
                                <a href="member_management.php?delete_member=<?= $member['customer_id'] ?>"
                                    class="btn btn-danger" onclick="return confirm('确定删除？')">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>