<?php
session_start();
require '../config.php';

// // 权限验证（仅管理员和店长可操作）
// if (!isset($_SESSION['user_id']) || ($_SESSION['role'] !== 'admin' && $_SESSION['role'] !== 'store_manager')) {
//     header("Location: login.php");
//     exit;
// }

// 处理所有促销操作
$error = '';
$success = '';

// 添加促销活动
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_promotion'])) {
    $promo_type = $_POST['promo_type'];
    $condition_amount = isset($_POST['condition_amount']) ? (float)$_POST['condition_amount'] : null;
    $discount_rate = (float)$_POST['discount_rate'];
    $start_date = $_POST['start_date'];
    $end_date = $_POST['end_date'];
    $applicable_products = isset($_POST['products']) ? json_encode($_POST['products']) : json_encode([]);

    // 初始化字段
    $condition_amount = null;
    $discount_rate = null;

    // 根据促销类型处理不同字段
    switch ($promo_type) {
        case '满减':
            $condition_amount = isset($_POST['condition_amount']) ? (float)$_POST['condition_amount'] : null;
            $discount_rate = isset($_POST['discount_amount']) ? (float)$_POST['discount_amount'] : null; // 关键修复
            break;
        case '折扣':
            $discount_rate = isset($_POST['discount_rate']) ? (float)$_POST['discount_rate'] : null;
            break;
    }

    try {

        $stmt = $pdo->prepare("
            INSERT INTO promotion 
            (promo_type, condition_amount, discount_rate, start_date, end_date, applicable_products)
            VALUES (?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $promo_type,
            $condition_amount,
            $discount_rate,
            $start_date,
            $end_date,
            $applicable_products
        ]);
        $success = "促销活动添加成功！";
    } catch (PDOException $e) {
        $error = "添加失败：" . $e->getMessage();
    }
}

// 删除促销活动
if (isset($_GET['delete_promotion'])) {
    $promo_id = (int)$_GET['delete_promotion'];
    try {
        $stmt = $pdo->prepare("DELETE FROM promotion WHERE promo_id = ?");
        $stmt->execute([$promo_id]);
        $success = "促销活动删除成功！";
    } catch (PDOException $e) {
        $error = "删除失败：" . $e->getMessage();
    }
}

// 获取所有促销活动和商品
$promotions = $pdo->query("
    SELECT * FROM promotion 
    ORDER BY start_date DESC
")->fetchAll();

$products = $pdo->query("
    SELECT product_id, model FROM products
")->fetchAll();
// var_dump($discount_rate);
?>
<!DOCTYPE html>
<html>

<head>
    <title>促销活动管理</title>
    <style>
        .container {
            max-width: 1200px;
            margin: 20px auto;
            padding: 20px;
        }

        .form-section {
            background: #f8f9fa;
            padding: 20px;
            border-radius: 8px;
            margin-bottom: 30px;
        }

        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: 600;
        }

        .form-group input,
        .form-group select {
            width: 100%;
            padding: 8px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .btn {
            padding: 8px 15px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            background: #3498db;
            color: white;
            margin-right: 10px;
        }

        .btn-danger {
            background: #e74c3c;
        }

        .alert {
            padding: 10px;
            margin: 15px 0;
            border-radius: 4px;
        }

        .alert-success {
            background: #d4edda;
            border: 1px solid #c3e6cb;
            color: #155724;
        }

        .alert-error {
            background: #f8d7da;
            border: 1px solid #f5c6cb;
            color: #721c24;
        }

        .promotion-table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
        }

        .promotion-table th,
        .promotion-table td {
            padding: 12px;
            border: 1px solid #ddd;
            text-align: left;
        }

        .promotion-table th {
            background: #f5f5f5;
        }

        .product-checkboxes {
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(200px, 1fr));
            gap: 10px;
            max-height: 200px;
            overflow-y: auto;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>促销活动管理</h1>

        <!-- 操作提示 -->
        <?php if ($success): ?>
            <div class="alert alert-success"><?= $success ?></div>
        <?php elseif ($error): ?>
            <div class="alert alert-error"><?= $error ?></div>
        <?php endif; ?>

        <!-- 添加促销表单 -->
        <div class="form-section">
            <h2>创建新促销</h2>
            <form method="POST" id="promoForm">
                <div class="form-group">
                    <label>促销类型</label>
                    <select name="promo_type" id="promoType" required>
                        <option value="满减">满减</option>
                        <option value="折扣">折扣</option>
                        <option value="赠品">赠品</option>
                    </select>
                </div>

                <!-- 满减条件 -->
                <div id="fullReduceSection" style="display:none;">
                    <div class="form-group">
                        <label>满减条件金额</label>
                        <input type="number" name="condition_amount" step="0.01" min="0">
                    </div>
                    <div class="form-group">
                        <label>减免金额</label>
                        <input type="number" name="discount_amount" step="0.01" min="0">
                    </div>
                </div>

                <!-- 折扣率 -->
                <div id="discountSection" style="display:none;">
                    <div class="form-group">
                        <label>折扣率（0.85 表示 85 折）</label>
                        <input type="number" name="discount_rate" step="0.01" min="0" max="1">
                    </div>
                </div>

                <!-- 赠品选择 -->
                <div id="giftSection" style="display:none;">
                    <div class="form-group">
                        <label>选择赠品商品</label>
                        <div class="product-checkboxes">
                            <?php foreach ($products as $product): ?>
                                <label>
                                    <input type="checkbox" name="products[]" value="<?= $product['product_id'] ?>">
                                    <?= htmlspecialchars($product['model']) ?>
                                </label>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>

                <div class="form-group">
                    <label>开始日期</label>
                    <input type="date" name="start_date" required>
                </div>
                <div class="form-group">
                    <label>结束日期</label>
                    <input type="date" name="end_date" required>
                </div>
                <button type="submit" name="add_promotion" class="btn">创建促销</button>
            </form>
        </div>

        <!-- 促销活动列表 -->
        <div class="form-section">
            <h2>进行中的促销活动</h2>
            <table class="promotion-table">
                <thead>
                    <tr>
                        <th>类型</th>
                        <th>优惠内容</th>
                        <th>有效期</th>
                        <th>适用商品</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($promotions as $promo):
                        $applicable = json_decode($promo['applicable_products'], true);
                    ?>
                        <tr>
                            <td><?= htmlspecialchars($promo['promo_type']) ?></td>
                            <td>
                                <?php switch ($promo['promo_type']):
                                    case '满减': ?>
                                        满 ¥<?= number_format($promo['condition_amount'], 2) ?> 减 ¥<?= number_format($promo['discount_rate'], 2) ?>
                                        <?php break; ?>
                                    <?php
                                    case '折扣': ?>
                                        <?= $promo['discount_rate'] * 100 ?>折
                                        <?php break; ?>
                                    <?php
                                    case '赠品': ?>
                                        赠品商品 <?= count($applicable) ?> 件
                                        <?php break; ?>
                                <?php endswitch; ?>
                            </td>
                            <td>
                                <?= date('Y-m-d', strtotime($promo['start_date'])) ?> ~
                                <?= date('Y-m-d', strtotime($promo['end_date'])) ?>
                            </td>
                            <td>
                                <?php
                                if (!empty($applicable)):
                                    $product_names = [];
                                    foreach ($products as $p) {
                                        if (in_array($p['product_id'], $applicable)) {
                                            $product_names[] = htmlspecialchars($p['model']);
                                        }
                                    }
                                    echo $product_names ? implode(', ', $product_names) : '全部商品';
                                else:
                                    echo '全部商品';
                                endif;
                                ?>
                            </td>
                            <td>
                                <a href="points_promotions.php?delete_promotion=<?= $promo['promo_id'] ?>"
                                    class="btn btn-danger" onclick="return confirm('确定删除？')">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <script>
        // 动态显示表单字段
        document.getElementById('promoType').addEventListener('change', function() {
            const type = this.value;

            // 清空所有输入框
            document.querySelectorAll('input[type="number"]').forEach(input => input.value = '');

            // 隐藏所有表单字段
            document.getElementById('fullReduceSection').style.display = 'none';
            document.getElementById('discountSection').style.display = 'none';
            document.getElementById('giftSection').style.display = 'none';

            switch (type) {
                case '满减':
                    document.getElementById('fullReduceSection').style.display = 'block';
                    break;
                case '折扣':
                    document.getElementById('discountSection').style.display = 'block';
                    break;
                case '赠品':
                    document.getElementById('giftSection').style.display = 'block';
                    break;
            }
        });

        // 触发初始状态
        document.getElementById('promoType').dispatchEvent(new Event('change'));
    </script>
</body>

</html>