<?php
session_start();
require '../config.php';

// // 权限验证（仅管理员和店长可操作）
// if (!isset($_SESSION['user_id']) || ($_SESSION['role'] !== 'admin' && $_SESSION['role'] !== 'store_manager')) {
//     header("Location: login.php");
//     exit;
// }

// 处理所有批发客户操作
$error = '';
$success = '';

// 添加客户
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['add_customer'])) {
    $customer_name = trim($_POST['customer_name']);
    $phone = trim($_POST['phone']);
    $credit_limit = (float)$_POST['credit_limit'];

    try {
        $stmt = $pdo->prepare("
            INSERT INTO customer 
            (customer_name, phone, customer_type, credit_limit)
            VALUES (?, ?, '批发客户', ?)
        ");
        $stmt->execute([$customer_name, $phone, $credit_limit]);
        $success = "客户添加成功！";
    } catch (PDOException $e) {
        $error = "添加失败：" . $e->getMessage();
    }
}

// 更新信用额度
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['update_credit'])) {
    $customer_id = (int)$_POST['customer_id'];
    $new_credit = (float)$_POST['new_credit'];

    try {
        $stmt = $pdo->prepare("
            UPDATE customer 
            SET credit_limit = ?
            WHERE customer_id = ?
        ");
        $stmt->execute([$new_credit, $customer_id]);
        $success = "信用额度更新成功！";
    } catch (PDOException $e) {
        $error = "更新失败：" . $e->getMessage();
    }
}

// 删除客户
if (isset($_GET['delete_customer'])) {
    $customer_id = (int)$_GET['delete_customer'];
    try {
        $stmt = $pdo->prepare("DELETE FROM customer WHERE customer_id = ?");
        $stmt->execute([$customer_id]);
        $success = "客户删除成功！";
    } catch (PDOException $e) {
        $error = "删除失败：" . $e->getMessage();
    }
}

// 获取所有批发客户及其历史采购
$customers = $pdo->query("
    SELECT c.*, SUM(s.total_amount) AS total_purchase 
    FROM customer c
    LEFT JOIN sales_order s ON c.customer_id = s.customer_id
    WHERE c.customer_type = '批发客户'
    GROUP BY c.customer_id
    ORDER BY c.customer_id DESC
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>批发客户管理</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h1>批发客户管理</h1>

        <!-- 操作提示 -->
        <?php if ($success): ?>
            <div class="alert alert-success"><?= $success ?></div>
        <?php elseif ($error): ?>
            <div class="alert alert-error"><?= $error ?></div>
        <?php endif; ?>

        <!-- 添加客户表单 -->
        <div class="form-section">
            <h2>新增批发客户</h2>
            <form method="POST">
                <div class="form-group">
                    <label>客户名称</label>
                    <input type="text" name="customer_name" required>
                </div>
                <div class="form-group">
                    <label>联系方式</label>
                    <input type="text" name="phone" required>
                </div>
                <div class="form-group">
                    <label>初始信用额度</label>
                    <input type="number" name="credit_limit" step="0.01" required>
                </div>
                <button type="submit" name="add_customer" class="btn">添加客户</button>
            </form>
        </div>

        <!-- 客户列表及管理 -->
        <div class="form-section">
            <h2>客户列表</h2>
            <table class="member-table">
                <thead>
                    <tr>
                        <th>客户名称</th>
                        <th>联系方式</th>
                        <th>信用额度</th>
                        <th>累计采购额</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($customers as $customer): ?>
                        <tr>
                            <td><?= htmlspecialchars($customer['customer_name']) ?></td>
                            <td><?= htmlspecialchars($customer['phone']) ?></td>
                            <td>
                                <form method="POST" style="display:inline;">
                                    <input type="hidden" name="customer_id" value="<?= $customer['customer_id'] ?>">
                                    ¥<input type="number" name="new_credit" value="<?= $customer['credit_limit'] ?>"
                                        step="0.01" style="width:120px;" onchange="this.form.submit()">
                                    <input type="hidden" name="update_credit">
                                </form>
                            </td>
                            <td>¥<?= number_format($customer['total_purchase'] ?? 0, 2) ?></td>
                            <td>
                                <a href="wholesale_customers.php?delete_customer=<?= $customer['customer_id'] ?>"
                                    class="btn btn-danger" onclick="return confirm('确定删除？')">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>