<?php
session_start();
require '../config.php';

// // 权限验证
// if (!isset($_SESSION['user_id']) || ($_SESSION['role'] !== 'finance' && $_SESSION['role'] !== 'admin')) {
//     header("Location: login.php");
//     exit;
// }

// 获取支出数据
$expenses = $pdo->query("
    SELECT 
        f.transaction_time,
        f.amount,
        f.payment_channel,
        s.supplier_name,
        po.order_no AS ref_order
    FROM financial_transaction f
    LEFT JOIN purchase_order po ON f.order_id = po.po_id
    LEFT JOIN supplier s ON po.supplier_id = s.supplier_id
    WHERE f.transaction_type = '支出'
    ORDER BY f.transaction_time DESC
")->fetchAll();

// 支出分类统计
$expense_summary = $pdo->query("
    SELECT 
        CASE 
            WHEN po.po_id IS NOT NULL THEN '采购支出'
            ELSE '运营支出' 
        END AS expense_type,
        SUM(f.amount) AS total_amount
    FROM financial_transaction f
    LEFT JOIN purchase_order po ON f.order_id = po.po_id
    WHERE f.transaction_type = '支出'
    GROUP BY expense_type
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>支出管理</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h1>支出管理</h1>

        <!-- 支出分类汇总 -->
        <div class="card">
            <h2>支出分类统计</h2>
            <table class="table">
                <thead>
                    <tr>
                        <th>支出类型</th>
                        <th>总金额</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($expense_summary as $row): ?>
                        <tr>
                            <td><?= htmlspecialchars($row['expense_type']) ?></td>
                            <td>¥<?= number_format($row['total_amount'], 2) ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- 详细支出记录 -->
        <div class="card">
            <h2>详细支出记录</h2>
            <table class="table">
                <thead>
                    <tr>
                        <th>时间</th>
                        <th>金额</th>
                        <th>支付方式</th>
                        <th>关联供应商</th>
                        <th>关联订单</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($expenses as $row): ?>
                        <tr>
                            <td><?= date('Y-m-d H:i', strtotime($row['transaction_time'])) ?></td>
                            <td>¥<?= number_format($row['amount'], 2) ?></td>
                            <td><?= htmlspecialchars($row['payment_channel'] ?? '--') ?></td>
                            <td><?= htmlspecialchars($row['supplier_name'] ?? '--') ?></td>
                            <td><?= htmlspecialchars($row['ref_order'] ?? '--') ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>