<?php
session_start();
require '../config.php';

// // 权限验证（仅财务和管理员可操作）
// if (!isset($_SESSION['user_id']) || ($_SESSION['role'] !== 'finance' && $_SESSION['role'] !== 'admin')) {
//     header("Location: login.php");
//     exit;
// }

// 获取收入数据
$income_data = $pdo->query("
    SELECT 
        CASE 
            WHEN f.transaction_type = '收入' THEN '销售收入'
            WHEN f.transaction_type = '应收款' THEN '应收回收'
            ELSE '其他收入' 
        END AS income_type,
        SUM(f.amount) AS total_amount,
        COUNT(*) AS transaction_count
    FROM financial_transaction f
    WHERE f.transaction_type IN ('收入', '应收款')
    GROUP BY income_type
")->fetchAll();

// 获取批发客户结算数据
$wholesale_settlements = $pdo->query("
    SELECT 
        c.customer_name,
        SUM(f.amount) AS settled_amount,
        MAX(f.transaction_time) AS last_settlement
    FROM financial_transaction f
    JOIN sales_order s ON f.order_id = s.order_id
    JOIN customer c ON s.customer_id = c.customer_id
    WHERE c.customer_type = '批发客户' 
    AND f.transaction_type = '应收款'
    GROUP BY c.customer_id
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>收入统计</title>
    <style>
        .container {
            max-width: 1200px;
            margin: 20px auto;
            padding: 0 15px;
        }

        .card {
            background: white;
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 20px;
        }

        .table {
            width: 100%;
            border-collapse: collapse;
        }

        .table th,
        .table td {
            padding: 12px;
            border: 1px solid #ddd;
            text-align: left;
        }

        .table th {
            background: #f5f5f5;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>收入统计</h1>

        <!-- 收入类型汇总 -->
        <div class="card">
            <h2>收入分类统计</h2>
            <table class="table">
                <thead>
                    <tr>
                        <th>收入类型</th>
                        <th>总金额</th>
                        <th>交易笔数</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($income_data as $row): ?>
                        <tr>
                            <td><?= htmlspecialchars($row['income_type']) ?></td>
                            <td>¥<?= number_format($row['total_amount'], 2) ?></td>
                            <td><?= $row['transaction_count'] ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- 批发客户结算 -->
        <div class="card">
            <h2>批发客户结算记录</h2>
            <table class="table">
                <thead>
                    <tr>
                        <th>客户名称</th>
                        <th>已结算金额</th>
                        <th>最后结算时间</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($wholesale_settlements as $row): ?>
                        <tr>
                            <td><?= htmlspecialchars($row['customer_name']) ?></td>
                            <td>¥<?= number_format($row['settled_amount'], 2) ?></td>
                            <td><?= date('Y-m-d H:i', strtotime($row['last_settlement'])) ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>