<?php
session_start();
require '../config.php';

// // 权限验证
// if (!isset($_SESSION['user_id']) || ($_SESSION['role'] !== 'finance' && $_SESSION['role'] !== 'admin')) {
//     header("Location: login.php");
//     exit;
// }

// 获取销售毛利数据
$gross_profit = $pdo->query("
    SELECT 
        SUM(s.total_amount) AS total_sales,
        SUM(i.cost_price * oi.quantity) AS total_cost,
        SUM(s.total_amount) - SUM(i.cost_price * oi.quantity) AS gross_profit
    FROM sales_order s
    JOIN order_item oi ON s.order_id = oi.order_id
    JOIN inventory i ON oi.product_id = i.product_id
")->fetch();

// 获取净利润数据
$net_profit = $pdo->query("
    SELECT 
        (SELECT SUM(amount) FROM financial_transaction WHERE transaction_type = '收入') AS total_income,
        (SELECT SUM(amount) FROM financial_transaction WHERE transaction_type = '支出') AS total_expense,
        (SELECT SUM(amount) FROM financial_transaction WHERE transaction_type = '应收款') AS total_receivable
")->fetch();
?>
<!DOCTYPE html>
<html>

<head>
    <title>利润分析</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h1>利润分析</h1>

        <!-- 销售毛利 -->
        <div class="card">
            <h2>销售毛利分析</h2>
            <table class="table">
                <tbody>
                    <tr>
                        <td>总销售额</td>
                        <td>¥<?= number_format($gross_profit['total_sales'], 2) ?></td>
                    </tr>
                    <tr>
                        <td>总销售成本</td>
                        <td>¥<?= number_format($gross_profit['total_cost'], 2) ?></td>
                    </tr>
                    <tr>
                        <td>销售毛利</td>
                        <td class="urgent">¥<?= number_format($gross_profit['gross_profit'], 2) ?></td>
                    </tr>
                </tbody>
            </table>
        </div>

        <!-- 净利润 -->
        <div class="card">
            <h2>净利润分析</h2>
            <table class="table">
                <tbody>
                    <tr>
                        <td>总收入（含应收）</td>
                        <td>¥<?= number_format($net_profit['total_income'] + $net_profit['total_receivable'], 2) ?></td>
                    </tr>
                    <tr>
                        <td>总支出</td>
                        <td>¥<?= number_format($net_profit['total_expense'], 2) ?></td>
                    </tr>
                    <tr>
                        <td>净利润</td>
                        <td class="urgent">
                            ¥<?= number_format(
                                    ($net_profit['total_income'] + $net_profit['total_receivable'])
                                        - $net_profit['total_expense'],
                                    2
                                ) ?>
                        </td>
                    </tr>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>