<?php
session_start();
require '../config.php';

// // 权限验证
// if (!isset($_SESSION['user_id']) || ($_SESSION['role'] !== 'finance' && $_SESSION['role'] !== 'admin')) {
//     header("Location: login.php");
//     exit;
// }

// 获取应收款数据
$receivables = $pdo->query("
    SELECT 
        c.customer_name,
        s.order_no,
        f.amount,
        f.transaction_time,
        DATEDIFF(NOW(), f.transaction_time) AS overdue_days
    FROM financial_transaction f
    JOIN sales_order s ON f.order_id = s.order_id
    JOIN customer c ON s.customer_id = c.customer_id
    WHERE f.transaction_type = '应收款'
    HAVING overdue_days > 30
")->fetchAll();

// 获取应付款数据
$payables = $pdo->query("
    SELECT 
        s.supplier_name,
        po.order_no,
        po.total_amount,
        po.expected_delivery,
        DATEDIFF(NOW(), po.expected_delivery) AS overdue_days
    FROM purchase_order po
    JOIN supplier s ON po.supplier_id = s.supplier_id
    WHERE po.status = '已完成'
    AND NOT EXISTS (
        SELECT 1 
        FROM financial_transaction f 
        WHERE f.order_id = po.po_id 
        AND f.transaction_type = '支出'
    )
    HAVING overdue_days > 0
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>应收应付管理</title>
    <style>
        .urgent {
            color: #e74c3c;
            font-weight: bold;
        }
    </style>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h1>应收应付管理</h1>

        <!-- 应收款提醒 -->
        <div class="card">
            <h2>逾期应收款</h2>
            <table class="table">
                <thead>
                    <tr>
                        <th>客户名称</th>
                        <th>订单号</th>
                        <th>金额</th>
                        <th>生成时间</th>
                        <th>逾期天数</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($receivables as $row): ?>
                        <tr class="<?= $row['overdue_days'] > 60 ? 'urgent' : '' ?>">
                            <td><?= htmlspecialchars($row['customer_name']) ?></td>
                            <td><?= htmlspecialchars($row['order_no']) ?></td>
                            <td>¥<?= number_format($row['amount'], 2) ?></td>
                            <td><?= date('Y-m-d', strtotime($row['transaction_time'])) ?></td>
                            <td><?= $row['overdue_days'] ?> 天</td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- 应付款管理 -->
        <div class="card">
            <h2>待支付应付款</h2>
            <table class="table">
                <thead>
                    <tr>
                        <th>供应商</th>
                        <th>采购单号</th>
                        <th>金额</th>
                        <th>应付款日期</th>
                        <th>逾期天数</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($payables as $row): ?>
                        <tr class="<?= $row['overdue_days'] > 30 ? 'urgent' : '' ?>">
                            <td><?= htmlspecialchars($row['supplier_name']) ?></td>
                            <td><?= htmlspecialchars($row['order_no']) ?></td>
                            <td>¥<?= number_format($row['total_amount'], 2) ?></td>
                            <td><?= date('Y-m-d', strtotime($row['expected_delivery'])) ?></td>
                            <td><?= $row['overdue_days'] ?> 天</td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>