<!-- 条码管理 -->

<?php
// barcode.php
session_start();
require '../config.php';

function check_login()
{
    if (empty($_SESSION['user_id'])) {
        header("Location: login.php");
        exit;
    }
}
check_login();

$action = $_GET['action'] ?? '';
$message = '';

// 处理条码绑定
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['bind_barcode'])) {
    try {
        $pdo->beginTransaction();

        // 验证条码唯一性
        $stmt = $pdo->prepare("SELECT product_id FROM products WHERE barcode = ?");
        $stmt->execute([$_POST['barcode']]);
        if ($stmt->fetch()) {
            throw new Exception("该条码已被使用");
        }

        // 更新商品条码
        $stmt = $pdo->prepare("UPDATE products SET barcode = ? WHERE product_id = ?");
        $stmt->execute([trim($_POST['barcode']), $_POST['product_id']]);

        $pdo->commit();
        $message = '<div class="success">条码绑定成功</div>';
    } catch (Exception $e) {
        $pdo->rollBack();
        $message = '<div class="error">错误：' . $e->getMessage() . '</div>';
    }
}

// 获取数据
$products = $pdo->query("SELECT product_id, sku, brand, model FROM products")->fetchAll();
$scanResult = null;

// 处理扫码查询
if ($action === 'query' && isset($_GET['barcode'])) {
    try {
        // 商品基础信息
        $stmt = $pdo->prepare("
            SELECT p.*, 
                   SUM(i.quantity) AS total_stock,
                   GROUP_CONCAT(w.warehouse_name SEPARATOR '|') AS warehouses
            FROM products p
            LEFT JOIN inventory i ON p.product_id = i.product_id
            LEFT JOIN warehouse w ON i.warehouse_id = w.warehouse_id
            WHERE p.barcode = ?
        ");
        $stmt->execute([$_GET['barcode']]);
        $scanResult = $stmt->fetch();

        if ($scanResult) {
            // 供应商信息
            // 修改供应商查询部分
            $stmt = $pdo->prepare("
 SELECT 
    s.supplier_name,
    MAX(po.actual_delivery) AS last_order_date,
    (SELECT poi.unit_price 
     FROM purchase_order_item poi 
     JOIN purchase_order po_sub ON poi.po_id = po_sub.po_id
     WHERE po_sub.supplier_id = s.supplier_id 
     ORDER BY po_sub.actual_delivery DESC 
     LIMIT 1) AS last_price
FROM supplier s
LEFT JOIN purchase_order po ON s.supplier_id = po.supplier_id
GROUP BY s.supplier_id
ORDER BY last_order_date DESC
LIMIT 3;
");
            $stmt->execute([$scanResult['product_id']]);
            $scanResult['suppliers'] = $stmt->fetchAll();

            // 库存详情
            $stmt = $pdo->prepare("
                SELECT i.batch_no, w.warehouse_name, i.quantity, i.expiry_date 
                FROM inventory i
                JOIN warehouse w ON i.warehouse_id = w.warehouse_id
                WHERE i.product_id = ?
            ");
            $stmt->execute([$scanResult['product_id']]);
            $scanResult['inventory'] = $stmt->fetchAll();
        }
    } catch (PDOException $e) {
        $message = '<div class="error">查询失败：' . $e->getMessage() . '</div>';
    }
}
?>
<!DOCTYPE html>
<html>

<head>
    <title>条码管理</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 20px;
        }

        .container {
            max-width: 1000px;
            margin: 0 auto;
        }

        .form-section {
            background: #f5f5f5;
            padding: 20px;
            border-radius: 8px;
            margin-bottom: 30px;
        }

        .scan-box {
            border: 2px dashed #3498db;
            padding: 20px;
            text-align: center;
        }

        .result-card {
            background: white;
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 15px;
            margin-top: 20px;
        }

        .grid {
            display: grid;
            grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
            gap: 15px;
        }

        .success {
            color: #2ecc71;
            background: #e8f5e9;
            padding: 10px;
            border-radius: 4px;
        }

        .error {
            color: #e74c3c;
            background: #fdeded;
            padding: 10px;
            border-radius: 4px;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 10px;
        }

        th,
        td {
            padding: 10px;
            border: 1px solid #ddd;
            text-align: left;
        }

        th {
            background: #f8f9fa;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>条码管理</h1>
        <?= $message ?>

        <!-- 条码绑定模块 -->
        <div class="form-section">
            <h2>条码绑定</h2>
            <form method="post">
                <div style="margin-bottom:15px">
                    <label>选择商品：</label>
                    <select name="product_id" required style="width:300px;padding:8px">
                        <?php foreach ($products as $p): ?>
                            <option value="<?= $p['product_id'] ?>"><?= $p['brand'] ?> <?= $p['model'] ?> (<?= $p['sku'] ?>)</option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div style="margin-bottom:15px">
                    <label>输入条码：</label>
                    <input type="text" name="barcode" required
                        pattern="\d{13}"
                        title="13位数字条码"
                        style="width:250px;padding:8px">
                </div>
                <button type="submit" name="bind_barcode"
                    style="background:#3498db;color:white;border:none;padding:10px 20px;border-radius:4px">
                    绑定条码
                </button>
            </form>
        </div>

        <!-- 扫码查询模块 -->
        <div class="form-section">
            <h2>扫码查询</h2>
            <div class="scan-box">
                <form method="get">
                    <input type="hidden" name="action" value="query">
                    <input type="text" name="barcode"
                        placeholder="输入或扫描条码..."
                        value="<?= $_GET['barcode'] ?? '' ?>"
                        style="width:300px;padding:10px;font-size:16px">
                    <button type="submit"
                        style="background:#27ae60;color:white;border:none;padding:10px 20px;border-radius:4px">
                        立即查询
                    </button>
                </form>
            </div>

            <?php if ($scanResult): ?>
                <div class="result-card">
                    <h3><?= $scanResult['brand'] ?> <?= $scanResult['model'] ?></h3>
                    <p>SKU: <?= $scanResult['sku'] ?> | 条码: <?= $scanResult['barcode'] ?></p>
                    <p>零售价: ¥<?= number_format($scanResult['unit_price'], 2) ?></p>

                    <h4>库存总览</h4>
                    <div class="grid">
                        <div class="result-card">
                            <p>总库存量: <?= $scanResult['total_stock'] ?? 0 ?></p>
                            <p>安全库存: <?= $scanResult['safety_stock'] ?></p>
                        </div>
                        <div class="result-card">
                            <h4>仓库分布</h4>
                            <ul>
                                <?php foreach (explode('|', $scanResult['warehouses']) as $wh): ?>
                                    <li><?= $wh ?></li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    </div>

                    <?php if (!empty($scanResult['suppliers'])): ?>
                        <h4>最近供应商</h4>
                        <table>
                            <tr>
                                <th>供应商</th>
                                <th>上次采购</th>
                                <th>平均价格</th>
                            </tr>
                            <?php foreach ($scanResult['suppliers'] as $s): ?>
                                <tr>
                                    <td><?= $s['supplier_name'] ?></td>
                                    <td><?= $s['last_purchase'] ?></td>
                                    <td>¥<?= number_format($s['avg_price'], 2) ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </table>
                    <?php endif; ?>

                    <h4>批次详情</h4>
                    <table>
                        <tr>
                            <th>批次号</th>
                            <th>仓库</th>
                            <th>数量</th>
                            <th>有效期</th>
                        </tr>
                        <?php foreach ($scanResult['inventory'] as $i): ?>
                            <tr>
                                <td><?= $i['batch_no'] ?></td>
                                <td><?= $i['warehouse_name'] ?></td>
                                <td><?= $i['quantity'] ?></td>
                                <td><?= $i['expiry_date'] ?? 'N/A' ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </table>
                </div>
            <?php elseif ($action === 'query'): ?>
                <div class="error" style="margin-top:15px">未找到匹配商品信息</div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>