<!-- 商品分类 -->

<?php
// category.php
require_once '../config.php';
// check_login();

// 获取分类树数据
try {
    $stmt = $pdo->query("
    SELECT 
        node.category_id,
        node.category_name,
        node.specifications->>'$.brand' AS brand,
        node.specifications->>'$.model' AS model,
        node.specifications->>'$.material' AS material,
        (COUNT(parent.category_id) - 1) AS depth,
        GROUP_CONCAT(parent.category_name ORDER BY parent.lft SEPARATOR ' > ') AS hierarchy_path
    FROM product_category AS node,
         product_category AS parent
    WHERE node.lft BETWEEN parent.lft AND parent.rgt
    GROUP BY node.category_id
    ORDER BY node.lft
");
    $categories = $stmt->fetchAll();
} catch (PDOException $e) {
    die("分类数据加载失败: " . $e->getMessage());
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $parentId = (int)$_POST['parent_id'];
    $categoryName = trim($_POST['category_name']);
    $specs = json_encode([
        'brand' => $_POST['brand'],
        'model' => $_POST['model'],
        'material' => $_POST['material']
    ]);

    try {
        $pdo->beginTransaction();

        // 动态获取父节点信息
        $parent = $parentId ?
            $pdo->query("SELECT lft, rgt FROM product_category WHERE category_id = $parentId")->fetch() :
            ['lft' => 0, 'rgt' => 0];

        // 计算新节点位置
        $newLeft = $parent['rgt'];
        $newRight = $newLeft + 1;

        // 更新现有节点
        $pdo->exec("UPDATE product_category SET rgt = rgt + 2 WHERE rgt >= $newLeft");
        $pdo->exec("UPDATE product_category SET lft = lft + 2 WHERE lft > $newLeft");

        // 插入新节点
        $stmt = $pdo->prepare("
        INSERT INTO product_category 
        (category_name, parent_id, specifications, lft, rgt)
        VALUES (?, ?, ?, ?, ?)
    ");
        $stmt->execute([
            $categoryName,
            $parentId ?: null,
            $specs,
            $newLeft,
            $newRight
        ]);

        $pdo->commit();
    } catch (Exception $e) {
        $pdo->rollBack();
        die("操作失败: " . $e->getMessage());
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <title>商品分类管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 此处插入用户提供的全局样式表 */


        /* 树形结构增强样式 */
        .tree-node {
            padding: 8px 0;
        }

        .category-depth-1 {
            margin-left: 30px;
        }

        .category-depth-2 {
            margin-left: 60px;
        }

        .spec-tag {
            display: inline-block;
            background: #f0f8ff;
            padding: 2px 8px;
            border-radius: 4px;
            margin-left: 10px;
        }

        /* 分类树样式增强 */
        .category-node {
            padding: 8px;
            border-left: 3px solid #3498db;
            margin: 5px 0;
            transition: all 0.3s;
        }

        .category-node:hover {
            background: #f8f9fa;
            transform: translateX(5px);
        }

        .spec-tag {
            background: #e3f2fd;
            border-radius: 12px;
            padding: 4px 10px;
            margin: 0 5px;
            font-size: 0.9em;
        }

        .category-path {
            color: #95a5a6;
            font-size: 0.85em;
            margin-left: 10px;
        }

        .category-tree {
            border: 1px solid #eee;
            padding: 20px;
            margin-top: 30px;
        }

        .category-node {
            padding: 12px;
            margin: 8px 0;
            background: #fff;
            border-radius: 4px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, 0.05);
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>商品分类管理系统</h2>

        <div class="form-container">
            <form method="post">
                <div class="form-group">
                    <label>父级分类：</label>
                    <select name="parent_id" required>
                        <option value="0">顶级分类</option>
                        <?php foreach ($categories as $cat): ?>
                            <option value="<?= $cat['category_id'] ?>">
                                <?= str_repeat('&nbsp;', $cat['depth'] * 3) ?>
                                <?= htmlspecialchars($cat['category_name']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label>分类名称：</label>
                    <input type="text" name="category_name" required>
                </div>

                <div class="form-group">
                    <label>规格参数：</label>
                    <div style="display: grid; grid-template-columns: repeat(3, 1fr); gap: 10px;">
                        <input type="text" name="brand" placeholder="品牌">
                        <input type="text" name="model" placeholder="型号">
                        <input type="text" name="material" placeholder="材质">
                    </div>
                </div>

                <button type="submit" class="btn-primary">创建分类</button>
            </form>
        </div>
        <div class="category-tree">
            <h3>现有分类体系</h3>
            <?php foreach ($categories as $cat): ?>
                <div class="category-node" style="margin-left: <?= $cat['depth'] * 30 ?>px;">
                    <span class="category-name"><?= htmlspecialchars($cat['category_name']) ?></span>
                    <span class="category-path">(<?= $cat['hierarchy_path'] ?>)</span>
                    <?php if ($cat['brand'] || $cat['model']): ?>
                        <div class="specs">
                            <?php if ($cat['brand']): ?>
                                <span class="spec-tag">品牌：<?= $cat['brand'] ?></span>
                            <?php endif; ?>
                            <?php if ($cat['model']): ?>
                                <span class="spec-tag">型号：<?= $cat['model'] ?></span>
                            <?php endif; ?>
                            <?php if ($cat['material']): ?>
                                <span class="spec-tag">材质：<?= $cat['material'] ?></span>
                            <?php endif; ?>
                        </div>
                    <?php endif; ?>
                </div>
            <?php endforeach; ?>
        </div>
        <div class="table-container">
            <table>
                <thead>
                    <tr>
                        <th>分类名称</th>
                        <th>品牌</th>
                        <th>型号</th>
                        <th>材质</th>
                        <th>层级</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($categories as $cat): ?>
                        <tr class="category-depth-<?= $cat['depth'] ?>">
                            <td><?= htmlspecialchars($cat['category_name']) ?></td>
                            <td><?= htmlspecialchars($cat['brand']) ?></td>
                            <td><?= htmlspecialchars($cat['model']) ?></td>
                            <td><?= htmlspecialchars($cat['material']) ?></td>
                            <td>第 <?= $cat['depth'] + 1 ?> 级</td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>