<?php
// index.php
declare(strict_types=1);
require_once './config.php';
session_start();

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ./login.php");
    exit;
}

// 获取用户信息（适配system_user表）
try {
    $stmt = $pdo->prepare("
        SELECT 
            username,
            role           
        FROM system_user 
        WHERE user_id = ?
    ");
    $stmt->execute([$_SESSION['user_id']]);
    $userInfo = $stmt->fetch(PDO::FETCH_ASSOC);
    // 角色映射配置
    $roleMap = [
        'admin'          => '系统管理员',
        'store_manager'  => '门店店长',
        'sales'          => '销售专员',
        'finance'        => '财务主管',
        'logistics'      => '物流调度员'
    ];
    $displayRole = $roleMap[$userInfo['role']] ?? '未授权用户';
} catch (PDOException $e) {
    die("用户信息获取失败: " . $e->getMessage());
}

// 系统核心模块
$modules = [
    [
        'name' => '商品与库存',
        'url' => './goods/index.php',
        'features' => [
            '✓ 多级分类管理（五金/水电/建材）',
            '✓ 批次/保质期追踪',
            '✓ 多仓库存实时同步',
            '✓ 条码扫描出入库',
            '✓ 智能库存预警'
        ]
    ],
    [
        'name' => '采购供应链',
        'url' => './purchase/index.php',
        'features' => [
            '✓ 供应商评分系统',
            '✓ 智能采购比价',
            '✓ 扫码入库验收',
            '✓ 采购成本分析',
            '✓ 供应商账期管理'
        ]
    ],
    [
        'name' => '销售中心',
        'url' => './sales/index.php',
        'features' => [
            '✓ 零售/批发模式切换',
            '✓ 多渠道支付集成',
            '✓ 赊销信用管理',
            '✓ 门店管理',
            '✓ 销售员业绩统计'
        ]
    ],
    [
        'name' => '客户关系',
        'url' => './crm/index.php',
        'features' => [
            '✓ 会员积分体系',
            '✓ 批发客户信用管理',
            '✓ 专属促销方案',
            '✓ 售后记录追踪',
            '✓ 客户消费分析'
        ]
    ],
    [
        'name' => '财务中心',
        'url' => './finance/index.php',
        'features' => [
            '✓ 应收应付对账',
            '✓ 多门店收支汇总',
            '✓ 毛利率自动计算',
            '✓ 电子发票系统',
            '✓ 成本利润分析'
        ]
    ],
    [
        'name' => '订单物流',
        'url' => './orders/index.php',
        'features' => [
            '✓ 线上订单处理',
            '✓ 智能配送调度',
            '✓ 安装维修管理',
            '✓ 物流状态追踪',
            '✓ 第三方物流对接'
        ]
    ],
    [
        'name' => '数据分析',
        'url' => './analytics/index.php',
        'features' => [
            '✓ 热销商品排行榜',
            '✓ 库存周转分析',
            '✓ 销售趋势预测',
            '✓ 客户价值评估',
            '✓ 多维度数据报表'
        ]
    ],
    [
        'name' => '系统设置',
        'url' => './system/index.php',
        'features' => [
            '✓ 多门店权限管理',
            '✓ 操作日志审计',
            '✓ 数据加密备份',
            '✓ 参数配置中心',
            '✓ 系统健康监控'
        ]
    ]
];
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>五金易管系统</title>
    <link href="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/5.1.3/css/bootstrap.min.css" rel="stylesheet">
    <style>
        /* 优化后的样式 */
        .dashboard-container {
            background: #f8f9fa;
            min-height: 100vh;
            padding: 2rem;
        }

        .header-bar {
            background: linear-gradient(135deg, #2c3e50, #3498db);
            color: white;
            padding: 1.5rem;
            margin: -2rem -2rem 2rem -2rem;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
        }

        .module-card {
            border: 1px solid rgba(44, 62, 80, 0.1);
            border-radius: 8px;
            transition: transform 0.3s ease;
            background: white;
        }

        .module-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 5px 15px rgba(44, 62, 80, 0.1);
            background: #e9f5ff;
        }

        .module-title {
            color: #2c3e50;
            font-weight: 600;
            border-bottom: 2px solid #3498db;
            padding-bottom: 0.5rem;
        }

        .feature-list li {
            color: #666;
            font-size: 0.95rem;
            padding: 4px 0;
        }
    </style>
</head>

<body>
    <div class="dashboard-container">
        <!-- 头部信息栏 -->
        <div class="header-bar">
            <div class="d-flex justify-content-between align-items-center">
                <div class="user-info">
                    <div class="h5 mb-0"><?= htmlspecialchars($userInfo['username']) ?></div>
                    <small class="text-light">角色：<?= htmlspecialchars($displayRole) ?></small>
                </div>
                <h1 class="header-title mb-0">五金易管系统</h1>
                <a href="./logout.php" class="btn btn-light">
                    <i class="fas fa-sign-out-alt"></i> 退出系统
                </a>
            </div>
        </div>

        <!-- 功能模块网格 -->
        <div class="container-fluid">
            <div class="row row-cols-1 row-cols-md-2 row-cols-lg-3 row-cols-xl-4 g-4">
                <?php foreach ($modules as $module): ?>
                    <div class="col">
                        <a href="<?= htmlspecialchars($module['url']) ?>" class="text-decoration-none">
                            <div class="card module-card h-100">
                                <div class="card-body">
                                    <h5 class="module-title text-center mb-3"><?= htmlspecialchars($module['name']) ?></h5>
                                    <ul class="feature-list list-unstyled mb-0">
                                        <?php foreach ($module['features'] as $feature): ?>
                                            <li><?= htmlspecialchars($feature) ?></li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </a>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
    </div>

    <script src="https://cdn.bootcdn.net/ajax/libs/font-awesome/5.15.4/js/all.min.js"></script>
</body>

</html>