<?php
session_start();
require '../config.php';

// 获取当前门店库存
$current_store = $pdo->prepare("
    SELECT warehouse_id FROM store 
    WHERE store_id = (SELECT store_id FROM system_user WHERE user_id = ?)
");
$current_store->execute([$_SESSION['user_id']]);
$store = $current_store->fetch();

// 处理订单接收
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['receive_order'])) {
    $order_id = (int)$_POST['order_id'];
    $delivery_method = $_POST['delivery_method']; // SELF_PICKUP/DELIVERY

    try {
        // 更新订单配送方式
        $pdo->prepare("
            UPDATE sales_order 
            SET delivery_status = '待出库',
                store_id = ?,
                order_type = '线上'
            WHERE order_id = ?
        ")->execute([$store['warehouse_id'], $order_id]);

        $_SESSION['success'] = "订单接收成功";
    } catch (PDOException $e) {
        $_SESSION['error'] = "操作失败：" . $e->getMessage();
    }
    header("Location: online_orders.php");
    exit;
}

// 获取待处理线上订单
$orders = $pdo->query("
    SELECT s.*, c.customer_name, c.phone 
    FROM sales_order s
    JOIN customer c ON s.customer_id = c.customer_id
    WHERE s.order_type = '线上'
    AND s.delivery_status = '待处理'
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>线上订单管理</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>待接收线上订单</h2>

        <div class="table-container">
            <table>
                <thead>
                    <tr>
                        <th>订单号</th>
                        <th>客户姓名</th>
                        <th>联系方式</th>
                        <th>总金额</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($orders as $order): ?>
                        <tr>
                            <td><?= $order['order_no'] ?></td>
                            <td><?= htmlspecialchars($order['customer_name']) ?></td>
                            <td><?= htmlspecialchars($order['phone']) ?></td>
                            <td>¥<?= number_format($order['total_amount'], 2) ?></td>
                            <td>
                                <div class="form-container" style="padding:10px;margin:0">
                                    <form method="POST">
                                        <div class="form-group" style="margin-bottom:0">
                                            <select name="delivery_method" required>
                                                <option value="SELF_PICKUP">自提</option>
                                                <option value="DELIVERY">配送</option>
                                            </select>
                                        </div>
                                        <div class="form-group" style="margin-bottom:0">
                                            <button type="submit" name="receive_order">接收</button>
                                        </div>
                                    </form>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>