<?php
session_start();
require '../config.php';

// 提交维修订单
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['create_service'])) {
    $order_id = (int)$_POST['order_id'];
    $technician_id = (int)$_POST['technician_id'];
    $description = $_POST['description'];

    try {
        $pdo->prepare("
            INSERT INTO service_order 
            (order_id, technician_id, service_type, scheduled_time, service_status)
            VALUES (?, ?, '维修', NOW(), '待处理')
        ")->execute([$order_id, $technician_id]);

        $_SESSION['success'] = "维修工单已创建";
    } catch (PDOException $e) {
        $_SESSION['error'] = "创建失败：" . $e->getMessage();
    }
    header("Location: service_management.php");
    exit;
}

// 获取待处理维修单
$services = $pdo->query("
    SELECT s.*, c.customer_name, u.username AS technician
    FROM service_order s
    JOIN sales_order so ON s.order_id = so.order_id
    JOIN customer c ON so.customer_id = c.customer_id
    LEFT JOIN system_user u ON s.technician_id = u.user_id
    WHERE s.service_type = '维修'
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>维修管理</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>维修工单管理</h2>

        <div class="form-container">
            <form method="POST">
                <div class="form-group">
                    <label>关联订单号</label>
                    <input type="text" name="order_id" required>
                </div>
                <div class="form-group">
                    <label>指派技师</label>
                    <select name="technician_id" required>
                        <?php foreach ($techs as $t): ?>
                            <option value="<?= $t['user_id'] ?>"><?= $t['username'] ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="form-group">
                    <button type="submit" name="create_service">创建工单</button>
                </div>
            </form>
        </div>

        <div class="table-container">
            <table>
                <thead>
                    <tr>
                        <th>工单号</th>
                        <th>客户名称</th>
                        <th>服务类型</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($services as $s): ?>
                        <tr>
                            <td>SV<?= $s['service_id'] ?></td>
                            <td><?= htmlspecialchars($s['customer_name']) ?></td>
                            <td><?= $s['service_type'] ?></td>
                            <td>
                                <a href="service_detail.php?id=<?= $s['service_id'] ?>" class="btn-link">查看详情</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>