<?php
require_once '../config.php';
// check_login();

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // 计算总金额
        $totalAmount = 0;
        $validItems = 0;

        foreach ($_POST['product_id'] as $i => $productId) {
            if (
                !empty($productId) &&
                isset($_POST['quantity'][$i]) && $_POST['quantity'][$i] > 0 &&
                isset($_POST['unit_price'][$i]) && $_POST['unit_price'][$i] > 0
            ) {
                $totalAmount += $_POST['quantity'][$i] * $_POST['unit_price'][$i];
                $validItems++;
            }
        }

        if ($validItems === 0) {
            throw new Exception("至少需要填写一条有效的采购明细");
        }

        $pdo->beginTransaction();

        // 插入订单头
        $orderNo = 'PO' . date('YmdHis');
        $stmt = $pdo->prepare("
            INSERT INTO purchase_order 
            (supplier_id, order_no, total_amount, status, created_by)
            VALUES (?, ?, ?, '待审批', ?)
        ");
        $stmt->execute([
            $_POST['supplier_id'],
            $orderNo,
            $totalAmount,
            1 // 当前用户ID
        ]);

        $poId = $pdo->lastInsertId();

        // 插入订单明细
        $stmtItem = $pdo->prepare("
            INSERT INTO purchase_order_item 
            (po_id, product_id, quantity, unit_price)
            VALUES (?, ?, ?, ?)
        ");

        foreach ($_POST['product_id'] as $i => $productId) {
            if (
                !empty($productId) &&
                isset($_POST['quantity'][$i]) && $_POST['quantity'][$i] > 0 &&
                isset($_POST['unit_price'][$i]) && $_POST['unit_price'][$i] > 0
            ) {
                $stmtItem->execute([
                    $poId,
                    $productId,
                    $_POST['quantity'][$i],
                    $_POST['unit_price'][$i]
                ]);
            }
        }

        $pdo->commit();
        header("Location: purchase_order.php?success=1");
        exit;
    } catch (Exception $e) {
        $pdo->rollBack();
        $errorMessage = $e->getMessage();
    }
}

// 处理审批操作
if (isset($_GET['action']) && $_GET['action'] === 'approve') {
    $stmt = $pdo->prepare("
        UPDATE purchase_order 
        SET status = '已批准' 
        WHERE po_id = ?
    ");
    $stmt->execute([$_GET['id']]);
    header("Location: purchase_order.php?success=1");
    exit;
}

// 获取数据
$suppliers = $pdo->query("SELECT * FROM supplier")->fetchAll();
$products = $pdo->query("SELECT * FROM products")->fetchAll();

$orders = $pdo->query("
    SELECT po.*, s.supplier_name,
    SUM(poi.quantity * poi.unit_price) AS total_cost,
    SUM(poi.quantity * p.unit_price) AS potential_income,
    po.total_amount AS order_amount
    FROM purchase_order po
    JOIN supplier s ON po.supplier_id = s.supplier_id
    JOIN purchase_order_item poi ON po.po_id = poi.po_id
    JOIN products p ON poi.product_id = p.product_id
    GROUP BY po.po_id
    ORDER BY po.po_id DESC
")->fetchAll();
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <title>采购订单管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .order-status {
            padding: 4px 8px;
            border-radius: 12px;
            font-size: 0.9em;
        }

        .status-pending {
            background: #f39c12;
        }

        .status-approved {
            background: #2ecc71;
        }

        .status-completed {
            background: #3498db;
        }

        .error-message {
            color: #e74c3c;
            padding: 10px;
        }

        .input-hint {
            color: #666;
            font-size: 0.9em;
        }
    </style>
</head>

<body>
    <div class="content-frame">
        <div class="container">
            <h2>采购订单管理</h2>

            <?php if (isset($errorMessage)): ?>
                <div class="error-message">错误：<?= $errorMessage ?></div>
            <?php endif; ?>

            <!-- 新建订单表单 -->
            <div class="form-container">
                <form method="post">
                    <div class="form-group">
                        <label>选择供应商</label>
                        <select name="supplier_id" required>
                            <?php foreach ($suppliers as $s): ?>
                                <option value="<?= $s['supplier_id'] ?>"
                                    <?= isset($_POST['supplier_id']) && $_POST['supplier_id'] == $s['supplier_id'] ? 'selected' : '' ?>>
                                    <?= $s['supplier_name'] ?> (评分：<?= str_repeat('★', $s['rating']) ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>采购商品明细 <span class="input-hint">（至少填写一行有效数据）</span></label>
                        <table class="order-items">
                            <thead>
                                <tr>
                                    <th>商品</th>
                                    <th>数量</th>
                                    <th>采购价</th>
                                    <th>市场价</th>
                                    <th>差价率</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php
                                $inputRows = isset($_POST['product_id']) ? count($_POST['product_id']) : 3;
                                for ($i = 0; $i < $inputRows; $i++):
                                    $productId = $_POST['product_id'][$i] ?? '';
                                    $quantity = $_POST['quantity'][$i] ?? '';
                                    $unitPrice = $_POST['unit_price'][$i] ?? '';

                                    $marketPrice = '';
                                    if ($productId) {
                                        $stmt = $pdo->prepare("SELECT unit_price FROM products WHERE product_id = ?");
                                        $stmt->execute([$productId]);
                                        $product = $stmt->fetch();
                                        $marketPrice = $product['unit_price'] ?? '';
                                    }

                                    $priceDiff = '';
                                    if ($marketPrice && $unitPrice) {
                                        $priceDiff = ($marketPrice - $unitPrice) / $marketPrice * 100;
                                    }
                                ?>
                                    <tr>
                                        <td>
                                            <select name="product_id[]">
                                                <option value="">选择商品</option>
                                                <?php foreach ($products as $p): ?>
                                                    <option value="<?= $p['product_id'] ?>"
                                                        <?= $p['product_id'] == $productId ? 'selected' : '' ?>>
                                                        <?= $p['brand'] ?> <?= $p['model'] ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                        <td>
                                            <input type="number" name="quantity[]"
                                                value="<?= $quantity ?>" min="0" step="1">
                                        </td>
                                        <td>
                                            <input type="number" name="unit_price[]"
                                                value="<?= $unitPrice ?>" step="0.01" min="0">
                                        </td>
                                        <td class="market-price">
                                            <?= $marketPrice ? number_format($marketPrice, 2) : '--' ?>
                                        </td>
                                        <td class="price-diff <?= $priceDiff > 0 ? 'positive' : 'negative' ?>">
                                            <?= $priceDiff ? number_format($priceDiff, 1) . '%' : '--' ?>
                                        </td>
                                    </tr>
                                <?php endfor; ?>
                            </tbody>
                            <tfoot>
                                <tr>
                                    <td colspan="4">订单总金额</td>
                                    <td class="total-amount">
                                        <?php
                                        $total = 0;
                                        if (isset($_POST['quantity']) && isset($_POST['unit_price'])) {
                                            foreach ($_POST['quantity'] as $i => $qty) {
                                                if ($qty > 0 && isset($_POST['unit_price'][$i]) && $_POST['unit_price'][$i] > 0) {
                                                    $total += $qty * $_POST['unit_price'][$i];
                                                }
                                            }
                                        }
                                        echo '￥' . number_format($total, 2);
                                        ?>
                                    </td>
                                </tr>
                            </tfoot>
                        </table>
                    </div>

                    <button type="submit" class="btn-primary">提交审批</button>
                    <button type="button" onclick="window.location.reload()" class="btn-cancel">重置表单</button>
                </form>
            </div>

            <!-- 订单列表 -->
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>订单号</th>
                            <th>供应商</th>
                            <th>总金额</th>
                            <th>毛利率</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($orders as $o):
                            $margin = ($o['potential_income'] - $o['total_cost']) / $o['potential_income'] * 100;
                        ?>
                            <tr>
                                <td><?= $o['order_no'] ?></td>
                                <td><?= $o['supplier_name'] ?></td>
                                <td>￥<?= number_format($o['order_amount'], 2) ?></td>
                                <td style="color:<?= $margin > 0 ? 'green' : 'red' ?>">
                                    <?= number_format($margin, 1) ?>%
                                </td>
                                <td>
                                    <span class="order-status status-<?= $o['status'] ?>">
                                        <?= $o['status'] ?>
                                    </span>
                                </td>
                                <td>
                                    <?php if ($o['status'] == '待审批'): ?>
                                        <a href="?action=approve&id=<?= $o['po_id'] ?>"
                                            class="btn-action approve">审批</a>
                                    <?php endif; ?>
                                    <a href="purchase_view.php?id=<?= $o['po_id'] ?>"
                                        class="btn-action view">详情</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>