<?php
require_once '../config.php';
// check_login();

// 获取订单ID
$orderId = $_GET['id'] ?? 0;

// 获取订单主信息
$stmt = $pdo->prepare("
    SELECT po.*, s.supplier_name, s.contact_person,
    SUM(poi.quantity * poi.unit_price) AS total_cost,
    SUM(poi.quantity * p.unit_price) AS potential_income
    FROM purchase_order po
    JOIN supplier s ON po.supplier_id = s.supplier_id
    JOIN purchase_order_item poi ON po.po_id = poi.po_id
    JOIN products p ON poi.product_id = p.product_id
    WHERE po.po_id = ?
");
$stmt->execute([$orderId]);
$order = $stmt->fetch(PDO::FETCH_ASSOC);

// 获取订单明细
$items = $pdo->prepare("
    SELECT poi.*, p.brand, p.model, p.sku, p.unit_price AS market_price
    FROM purchase_order_item poi
    JOIN products p ON poi.product_id = p.product_id
    WHERE poi.po_id = ?
");
$items->execute([$orderId]);
$orderItems = $items->fetchAll();

// 计算毛利率
if ($order && $order['potential_income'] > 0) {
    $grossMargin = ($order['potential_income'] - $order['total_cost']) / $order['potential_income'] * 100;
} else {
    $grossMargin = 0;
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <title>采购订单详情</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .order-header {
            background: #f8f9fa;
            padding: 20px;
            margin-bottom: 20px;
            border-radius: 8px;
        }

        .summary-item {
            display: flex;
            justify-content: space-between;
            margin-bottom: 10px;
            padding: 8px;
            background: #fff;
            border-radius: 4px;
        }

        .action-buttons {
            margin-top: 20px;
            padding: 15px 0;
            border-top: 1px solid #eee;
        }

        .btn-action.back {
            background: #3498db;
            color: white;
            padding: 8px 15px;
            border-radius: 4px;
            text-decoration: none;
        }

        .btn-action.approve {
            background: #2ecc71;
            margin-left: 10px;
        }

        .error-message {
            text-align: center;
            padding: 40px;
            background: #ffeef0;
            border-radius: 8px;
        }

        .sku {
            font-size: 0.9em;
            color: #666;
            margin-top: 5px;
        }
    </style>
</head>

<body>

    <div class="content-frame">
        <div class="container">
            <?php if ($order): ?>
                <div class="order-header">
                    <h3>采购订单 #<?= $order['order_no'] ?></h3>
                    <div class="summary-item">
                        <span>供应商：</span>
                        <span><?= $order['supplier_name'] ?>（联系人：<?= $order['contact_person'] ?>）</span>
                    </div>
                    <div class="summary-item">
                        <span>订单状态：</span>
                        <span class="order-status status-<?= $order['status'] ?>">
                            <?= $order['status'] ?>
                        </span>
                    </div>
                    <div class="summary-item">
                        <span>总采购成本：</span>
                        <span>￥<?= number_format($order['total_cost'], 2) ?></span>
                    </div>
                    <div class="summary-item">
                        <span>预计毛利：</span>
                        <span style="color:<?= $grossMargin > 0 ? 'green' : 'red' ?>">
                            <?= number_format($grossMargin, 1) ?>%
                        </span>
                    </div>
                </div>

                <div class="table-container">
                    <table>
                        <thead>
                            <tr>
                                <th>商品信息</th>
                                <th>采购单价</th>
                                <th>市场单价</th>
                                <th>采购数量</th>
                                <th>差价率</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($orderItems as $item):
                                $priceDiff = ($item['market_price'] - $item['unit_price']) / $item['market_price'] * 100;
                            ?>
                                <tr>
                                    <td>
                                        <?= $item['brand'] ?> <?= $item['model'] ?>
                                        <div class="sku">SKU: <?= $item['sku'] ?></div>
                                    </td>
                                    <td>￥<?= number_format($item['unit_price'], 2) ?></td>
                                    <td>￥<?= number_format($item['market_price'], 2) ?></td>
                                    <td><?= $item['quantity'] ?></td>
                                    <td style="color:<?= $priceDiff > 0 ? 'green' : 'red' ?>">
                                        <?= number_format($priceDiff, 1) ?>%
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>

                <div class="action-buttons">
                    <a href="purchase_order.php" class="btn-action back">返回列表</a>
                    <?php if ($order['status'] == '待审批'): ?>
                        <a href="purchase_order.php?action=approve&id=<?= $orderId ?>"
                            class="btn-action approve">立即审批</a>
                    <?php endif; ?>
                </div>

            <?php else: ?>
                <div class="error-message">
                    <h3>订单不存在或已被删除</h3>
                    <a href="purchase_order.php" class="btn-action back">返回列表</a>
                </div>
            <?php endif; ?>
        </div>
    </div>

</body>

</html>