<?php
require_once '../config.php';
// check_login();

// 处理入库操作
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        $pdo->beginTransaction();

        // 获取采购订单信息
        $stmtPo = $pdo->prepare("
            SELECT poi.product_id, poi.unit_price AS cost_price, 
                   p.unit_price AS market_price
            FROM purchase_order_item poi
            JOIN products p ON poi.product_id = p.product_id
            WHERE poi.po_id = ?
        ");
        $stmtPo->execute([$_POST['po_id']]);
        $poItems = $stmtPo->fetchAll();

        if (count($poItems) === 0) {
            throw new Exception("采购订单中没有有效商品");
        }

        // 自动生成批次号（格式：订单号-序号）
        $stmtOrderNo = $pdo->prepare("SELECT order_no FROM purchase_order WHERE po_id = ?");
        $stmtOrderNo->execute([$_POST['po_id']]);
        $orderNo = $stmtOrderNo->fetchColumn();
        $batchNo = $orderNo . '-' . str_pad(mt_rand(1, 999), 3, '0', STR_PAD_LEFT);

        // 插入库存记录
        $stmt = $pdo->prepare("
            INSERT INTO inventory 
            (product_id, warehouse_id, batch_no, quantity, 
             production_date, expiry_date, cost_price, last_sync)
            VALUES (?, ?, ?, ?, ?, ?, ?, NOW())
            ON DUPLICATE KEY UPDATE 
                quantity = quantity + VALUES(quantity),
                last_sync = NOW()
        ");

        foreach ($poItems as $item) {
            $stmt->execute([
                $item['product_id'],
                $_POST['warehouse_id'],
                $batchNo,
                $_POST['quantity'],
                $_POST['production_date'],
                $_POST['expiry_date'],
                $item['cost_price']
            ]);
        }

        // 更新采购订单状态
        $stmt = $pdo->prepare("
            UPDATE purchase_order 
            SET status = '已完成' 
            WHERE po_id = ?
        ");
        $stmt->execute([$_POST['po_id']]);

        $pdo->commit();
        header("Location: stock_in.php?success=1");
        exit;
    } catch (Exception $e) {
        $pdo->rollBack();
        die("操作失败: " . $e->getMessage());
    }
}

// 获取待入库订单
$pending_orders = $pdo->query("
    SELECT po.po_id, po.order_no, s.supplier_name,
    p.product_id, p.brand, p.model, p.unit_price
    FROM purchase_order po
    JOIN supplier s ON po.supplier_id = s.supplier_id
    JOIN purchase_order_item poi ON po.po_id = poi.po_id
    JOIN products p ON poi.product_id = p.product_id
    WHERE po.status = '已批准'
")->fetchAll();

// 获取仓库列表
$warehouses = $pdo->query("SELECT * FROM warehouse")->fetchAll();

// 获取历史入库记录（显示最近50条）
$history = $pdo->query("
    SELECT i.*, p.brand, p.model, p.unit_price AS market_price,
           w.warehouse_name, po.order_no,
           DATE_FORMAT(i.last_sync, '%Y-%m-%d %H:%i') AS formatted_time
    FROM inventory i
    JOIN products p ON i.product_id = p.product_id
    JOIN warehouse w ON i.warehouse_id = w.warehouse_id
    LEFT JOIN purchase_order po ON i.batch_no LIKE CONCAT(po.order_no, '%')
    ORDER BY i.inventory_id DESC LIMIT 50
")->fetchAll();
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <title>入库管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 价格差异指示器 */
        .price-diff {
            font-weight: bold;
        }

        .positive {
            color: #2ecc71;
        }

        .negative {
            color: #e74c3c;
        }

        /* 表格时间显示 */
        td:nth-child(1) {
            min-width: 120px;
        }

        /* 批次号样式 */
        td:nth-child(3) {
            font-family: monospace;
            color: #3498db;
        }
    </style>
</head>

<body>
    <div class="content-frame">
        <div class="container">
            <h2>入库管理</h2>

            <!-- 入库表单 -->
            <div class="form-container">
                <form method="post">
                    <div class="form-group">
                        <label>选择采购订单</label>
                        <select name="po_id" required>
                            <?php foreach ($pending_orders as $o): ?>
                                <option value="<?= $o['po_id'] ?>">
                                    <?= $o['order_no'] ?> - <?= $o['brand'] ?> <?= $o['model'] ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>入库仓库</label>
                        <select name="warehouse_id" required>
                            <?php foreach ($warehouses as $w): ?>
                                <option value="<?= $w['warehouse_id'] ?>">
                                    <?= $w['warehouse_name'] ?> (<?= $w['type'] ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>入库数量</label>
                        <input type="number" name="quantity" required min="1" value="1">
                    </div>

                    <div class="form-group">
                        <label>生产日期</label>
                        <input type="date" name="production_date" required
                            value="<?= date('Y-m-d') ?>">
                    </div>

                    <div class="form-group">
                        <label>过期日期</label>
                        <input type="date" name="expiry_date"
                            value="<?= date('Y-m-d', strtotime('+1 year')) ?>">
                    </div>

                    <button type="submit" class="btn-primary">确认入库</button>
                </form>
            </div>

            <!-- 入库记录 -->
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>入库时间</th>
                            <th>商品信息</th>
                            <th>批次号</th>
                            <th>仓库</th>
                            <th>采购价</th>
                            <th>当前售价</th>
                            <th>差价率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($history as $h):
                            // 计算差价率
                            $priceDiff = 0;
                            if ($h['market_price'] > 0) {
                                $priceDiff = (($h['market_price'] - $h['cost_price']) / $h['market_price']) * 100;
                            }
                        ?>
                            <tr>
                                <td><?= $h['formatted_time'] ?></td>
                                <td><?= $h['brand'] ?> <?= $h['model'] ?></td>
                                <td><?= $h['batch_no'] ?></td>
                                <td><?= $h['warehouse_name'] ?></td>
                                <td>￥<?= number_format($h['cost_price'], 2) ?></td>
                                <td>￥<?= number_format($h['market_price'], 2) ?></td>
                                <td style="color:<?= $priceDiff > 0 ? 'green' : 'red' ?>">
                                    <?= $h['market_price'] > 0 ? number_format($priceDiff, 1) . '%' : 'N/A' ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>