<?php
require_once '../config.php';
// check_login();

// 处理所有操作
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 添加/编辑供应商
    if (isset($_POST['save'])) {
        try {
            $data = [
                $_POST['supplier_name'],
                $_POST['contact_person'],
                $_POST['rating'],
                $_POST['payment_terms'] ?? ''
            ];

            if ($_POST['save'] === 'update') {
                $data[] = $_POST['supplier_id'];
                $stmt = $pdo->prepare("
                    UPDATE supplier SET
                        supplier_name = ?,
                        contact_person = ?,
                        rating = ?,
                        payment_terms = ?
                    WHERE supplier_id = ?
                ");
            } else {
                $stmt = $pdo->prepare("
                    INSERT INTO supplier 
                    (supplier_name, contact_person, rating, payment_terms)
                    VALUES (?, ?, ?, ?)
                ");
            }

            $stmt->execute($data);
            header("Location: supplier.php?success=1");
            exit;
        } catch (PDOException $e) {
            die("操作失败: " . $e->getMessage());
        }
    }
}

// 处理删除操作
if (isset($_GET['action']) && $_GET['action'] === 'delete') {
    try {
        $stmt = $pdo->prepare("DELETE FROM supplier WHERE supplier_id = ?");
        $stmt->execute([$_GET['id']]);
        header("Location: supplier.php?success=1");
        exit;
    } catch (PDOException $e) {
        die("删除失败: " . $e->getMessage());
    }
}

// 准备编辑数据
$editData = [];
if (isset($_GET['action']) && $_GET['action'] === 'edit') {
    $stmt = $pdo->prepare("SELECT * FROM supplier WHERE supplier_id = ?");
    $stmt->execute([$_GET['id']]);
    $editData = $stmt->fetch(PDO::FETCH_ASSOC);
}

// 获取供应商列表
$suppliers = $pdo->query("
    SELECT s.*, 
    COUNT(po.po_id) AS order_count,
    MAX(po.actual_delivery) AS last_transaction
    FROM supplier s
    LEFT JOIN purchase_order po ON s.supplier_id = po.supplier_id
    GROUP BY s.supplier_id
")->fetchAll();
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <title>供应商管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .rating-stars {
            color: #f39c12;
        }

        .edit-form {
            background: #f8f9fa;
            padding: 15px;
            margin-bottom: 20px;
        }

        .btn-cancel {
            background: #95a5a6;
            color: white;
            padding: 8px 15px;
            border-radius: 4px;
            text-decoration: none;
            margin-left: 10px;
        }

        .btn-cancel:hover {
            background: #7f8c8d;
        }

        .transaction-status {
            font-size: 0.9em;
            color: #666;
            line-height: 1.4;
        }

        .status-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 12px;
            background: #3498db;
            color: white;
            font-size: 0.9em;
        }

        .status-tag.new {
            background: #2ecc71;
        }
    </style>
</head>

<body>

    <div class="content-frame">
        <div class="container">
            <h2>供应商管理</h2>

            <!-- 编辑/添加表单 -->
            <div class="form-container edit-form">
                <form method="post">
                    <?php if (isset($editData['supplier_id'])): ?>
                        <input type="hidden" name="supplier_id" value="<?= $editData['supplier_id'] ?>">
                        <input type="hidden" name="save" value="update">
                    <?php else: ?>
                        <input type="hidden" name="save" value="create">
                    <?php endif; ?>

                    <div class="form-group">
                        <label>供应商名称</label>
                        <input type="text" name="supplier_name"
                            value="<?= $editData['supplier_name'] ?? '' ?>" required>
                    </div>

                    <div class="form-group">
                        <label>联系人</label>
                        <input type="text" name="contact_person"
                            value="<?= $editData['contact_person'] ?? '' ?>">
                    </div>

                    <div class="form-group">
                        <label>信用评分</label>
                        <select name="rating" class="star-rating">
                            <?php for ($i = 1; $i <= 5; $i++): ?>
                                <option value="<?= $i ?>" <?= isset($editData['rating']) && $editData['rating'] == $i ? 'selected' : '' ?>>
                                    <?= str_repeat('★', $i) ?>
                                </option>
                            <?php endfor; ?>
                        </select>
                    </div>

                    <button type="submit" class="btn-primary">
                      保存修改/添加供应商
                    </button>

                    <?php if (isset($editData)): ?>
                        <a href="supplier.php" class="btn-cancel">取消编辑</a>
                    <?php endif; ?>
                </form>
            </div>

            <!-- 供应商列表 -->
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>供应商名称</th>
                            <th>联系人</th>
                            <th>交易状态</th>
                            <th>信用评分</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($suppliers as $s): ?>
                            <tr>
                                <td><?= $s['supplier_name'] ?></td>
                                <td><?= $s['contact_person'] ?></td>
                                <td>
                                    <?php if ($s['order_count'] > 0): ?>
                                        <div class="transaction-status">
                                            最近交易：<?= $s['last_transaction'] ?><br>
                                            累计订单：<?= $s['order_count'] ?>笔
                                        </div>
                                    <?php else: ?>
                                        <span class="status-tag new">新供应商</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <span class="rating-stars"><?= str_repeat('★', $s['rating']) ?></span>
                                </td>
                                <td>
                                    <a href="?action=edit&id=<?= $s['supplier_id'] ?>" class="btn-action edit">编辑</a>
                                    <a href="?action=delete&id=<?= $s['supplier_id'] ?>"
                                        class="btn-action delete"
                                        onclick="return confirm('确定删除该供应商？')">删除</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

</body>

</html>