<?php
session_start();
require '../config.php';

// 获取当前门店ID
$store_id = $_SESSION['store_id'] ?? 0;

// 获取日期范围
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d');
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// 获取日销售统计数据
$daily_sales = $pdo->prepare("
    SELECT 
        DATE(s.created_at) AS sale_date,
        SUM(s.total_amount) AS total_sales,
        COUNT(*) AS order_count,
        u.username AS salesperson
    FROM sales_order s
    JOIN system_user u ON s.salesperson_id = u.user_id
    WHERE s.store_id = ?
    AND s.created_at BETWEEN ? AND ?
    GROUP BY sale_date, s.salesperson_id
    ORDER BY sale_date DESC
");
$daily_sales->execute([$store_id, $start_date, $end_date]);
$daily_sales_data = $daily_sales->fetchAll();

// 获取按天、周、月的销售统计数据
// 修改后的查询
$sales_report = $pdo->prepare("
    SELECT 
        DATE_FORMAT(s.created_at, '%Y-%m-%d') AS period_day,
        DATE_FORMAT(s.created_at, '%Y-%u') AS period_week,
        DATE_FORMAT(s.created_at, '%Y-%m') AS period_month,
        SUM(s.total_amount) AS total_sales
    FROM sales_order s
    WHERE s.store_id = ?
    AND s.created_at BETWEEN ? AND ?
    GROUP BY period_day, period_week, period_month
    ORDER BY period_day DESC, period_week DESC, period_month DESC
");
$sales_report->execute([$store_id, $start_date, $end_date]);
$sales_report_data = $sales_report->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>销售对账</title>
    <style>
        /* 基础样式 */
        body {
            font-family: Arial, sans-serif;
            background: #f8f9fa;
            margin: 0;
        }

        .container {
            max-width: 1200px;
            margin: 20px auto;
            padding: 0 15px;
        }

        /* 模块标题 */
        .section-title {
            border-left: 4px solid #3498db;
            padding-left: 12px;
            margin: 40px 0 20px;
            color: #2c3e50;
        }

        /* 销售数据表格 */
        .sales-table {
            width: 100%;
            border-collapse: collapse;
        }

        .sales-table th,
        .sales-table td {
            padding: 12px;
            border: 1px solid #ddd;
            text-align: left;
        }

        .sales-table th {
            background: #f5f5f5;
        }

        .sales-table tr:nth-child(even) {
            background: #f9f9f9;
        }

        .sales-table tr:hover {
            background: #f1f1f1;
        }

        /* 报表卡片 */
        .report-grid {
            display: grid;
            grid-template-columns: repeat(3, 1fr);
            gap: 20px;
            margin-top: 30px;
        }

        .report-card {
            background: white;
            border: 1px solid #ddd;
            border-radius: 6px;
            padding: 20px;
        }

        .report-title {
            font-size: 1.2em;
            margin-bottom: 15px;
        }

        .report-value {
            font-size: 1.5em;
            color: #3498db;
        }

        /* 表单元素 */
        input[type="date"],
        button {
            padding: 8px 12px;
            border: 1px solid #ced4da;
            border-radius: 4px;
            margin: 5px 0;
        }

        button {
            background: #3498db;
            color: white;
            border: none;
            cursor: pointer;
        }

        button:hover {
            background: #2980b9;
        }
    </style>
</head>

<body>
    <div class="container">
        <!-- 日销售统计 -->
        <h2 class="section-title">日销售统计</h2>

        <!-- 日期筛选表单 -->
        <form method="GET">
            <label>开始日期：</label>
            <input type="date" name="start_date" value="<?= htmlspecialchars($start_date) ?>">
            <label>结束日期：</label>
            <input type="date" name="end_date" value="<?= htmlspecialchars($end_date) ?>">
            <button type="submit">查询</button>
        </form>

        <!-- 销售数据表格 -->
        <table class="sales-table">
            <thead>
                <tr>
                    <th>日期</th>
                    <th>销售员</th>
                    <th>订单数</th>
                    <th>销售额</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($daily_sales_data as $row): ?>
                    <tr>
                        <td><?= htmlspecialchars($row['sale_date']) ?></td>
                        <td><?= htmlspecialchars($row['salesperson']) ?></td>
                        <td><?= htmlspecialchars($row['order_count']) ?></td>
                        <td>¥<?= number_format($row['total_sales'], 2) ?></td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>

        <!-- 按天、周、月统计 -->
        <h2 class="section-title">销售报表</h2>
        <div class="report-grid">
            <div class="report-card">
                <div class="report-title">日销售额</div>
                <div class="report-value">
                    ¥<?= number_format(array_sum(array_column($sales_report_data, 'total_sales')), 2) ?>
                </div>
            </div>
            <div class="report-card">
                <div class="report-title">周销售额</div>
                <div class="report-value">
                    ¥<?= number_format(array_sum(array_column($sales_report_data, 'total_sales')), 2) ?>
                </div>
            </div>
            <div class="report-card">
                <div class="report-title">月销售额</div>
                <div class="report-value">
                    ¥<?= number_format(array_sum(array_column($sales_report_data, 'total_sales')), 2) ?>
                </div>
            </div>
        </div>
    </div>
</body>

</html>