<?php
session_start();
require '../config.php';

// 添加门店
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $storeName = $_POST['store_name'];
    $warehouseId = (int)$_POST['warehouse_id'];
    $managerId = (int)$_POST['manager_id'];

    $pdo->prepare("
        INSERT INTO store 
        (store_name, warehouse_id, manager_id)
        VALUES (?, ?, ?)
    ")->execute([$storeName, $warehouseId, $managerId]);
}
// 新增：获取所有门店信息
$stores = $pdo->query("
    SELECT s.store_id, s.store_name, 
           w.warehouse_name, w.type AS warehouse_type,
           u.username AS manager_name
    FROM store s
    JOIN warehouse w USING(warehouse_id)
    JOIN system_user u ON s.manager_id = u.user_id
    ORDER BY s.store_id DESC
")->fetchAll();
// 获取仓库和店长列表
$warehouses = $pdo->query("SELECT * FROM warehouse")->fetchAll();
$managers = $pdo->query("SELECT * FROM system_user WHERE role IN ('store_manager', 'admin')")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>门店管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .form-container {
            max-width: 600px;
            margin: 20px auto;
        }

        .dual-select {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 20px;
        }

        .store-list {
            margin-top: 30px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }

        .store-list table {
            width: 100%;
            border-collapse: collapse;
        }

        .store-list th,
        .store-list td {
            padding: 12px;
            border-bottom: 1px solid #ddd;
            text-align: left;
        }

        .current-store {
            background-color: #f0f8ff;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>门店管理</h2>
        <div class="form-container">
            <form method="POST">
                <div class="form-group">
                    <label>门店名称</label>
                    <input type="text" name="store_name" required>
                </div>

                <div class="dual-select">
                    <div>
                        <label>关联仓库</label>
                        <select name="warehouse_id" required>
                            <?php foreach ($warehouses as $w): ?>
                                <option value="<?= $w['warehouse_id'] ?>">
                                    <?= $w['warehouse_name'] ?> (<?= $w['type'] ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div>
                        <label>门店店长</label>
                        <select name="manager_id" required>
                            <?php foreach ($managers as $m): ?>
                                <option value="<?= $m['user_id'] ?>">
                                    <?= $m['username'] ?> (<?= $m['role'] ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </div>

                <button type="submit" class="btn-primary">添加门店</button>
            </form>
        </div>
        <div class="store-list">
            <h3> 门店列表</h3>
            <table>
                <thead>
                    <tr>
                        <th>门店名称</th>
                        <th>仓库</th>
                        <th>仓库类型</th>
                        <th>店长</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($stores as $store): ?>
                        <tr <?= $store['store_id'] == $_SESSION['store_id'] ? 'class="current-store"' : '' ?>>
                            <td><?= htmlspecialchars($store['store_name']) ?></td>
                            <td><?= htmlspecialchars($store['warehouse_name']) ?></td>
                            <td><?= htmlspecialchars($store['warehouse_type']) ?></td>
                            <td><?= htmlspecialchars($store['manager_name']) ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>

</html>
