<?php
session_start();
require '../config.php';

// 备份目录配置
$backup_dir = __DIR__ . '/../backups/';
if (!file_exists($backup_dir)) mkdir($backup_dir, 0755, true);

// 执行手动备份
if (isset($_GET['action'])) {
    switch ($_GET['action']) {
        case 'backup':
            $filename = 'backup_' . date('YmdHis') . '.sql';
            $full_path = $backup_dir . $filename;

            try {
                // 验证用户会话
                if (!isset($_SESSION['user_id'])) {
                    throw new Exception("用户未登录");
                }
                $operator_id = $_SESSION['user_id'];

                // 执行备份命令
                if (!file_exists(MYSQLDUMP_PATH)) {
                    die("错误：未找到 mysqldump，请检查 config.php 中的 MYSQL_BIN_PATH 配置");
                }
                $mysqldump_path = '"' . MYSQLDUMP_PATH . '"'; // 路径用双引号包裹，兼容空格
                $command = "{$mysqldump_path} -u" . DB_USER . " -p\"" . DB_PASS . "\" " . DB_NAME . " > \"{$full_path}\" 2>&1";
                exec($command, $output, $result);

                // 打印完整错误信息
                if ($result !== 0) {
                    echo "备份失败，错误详情：<br>";
                    echo "<pre>" . implode("\n", $output) . "</pre>";
                } else {
                    echo "备份成功！文件路径：" . $full_path;
                }

                if ($result !== 0) {
                    die("备份失败，错误信息：" . implode("\n", $output));
                }
                echo "备份成功！文件路径：{$full_path}";

                if ($result !== 0) {
                    throw new Exception("mysqldump失败，错误码: $result");
                }

                // 等待文件写入完成（最多5秒）
                $max_retries = 10;
                $file_size = 0;
                do {
                    clearstatcache(true, $full_path);
                    $file_size = filesize($full_path);
                    if ($file_size > 0) break;
                    usleep(500000); // 500ms
                } while ($max_retries-- > 0);

                if ($file_size === 0) {
                    throw new Exception("文件写入失败");
                }

                // 验证用户存在性
                $stmt = $pdo->prepare("SELECT user_id FROM system_user WHERE user_id = ?");
                $stmt->execute([$operator_id]);
                if (!$stmt->fetch()) {
                    throw new Exception("操作员ID不存在: $operator_id");
                }

                // 插入备份记录
                $insertStmt = $pdo->prepare("
            INSERT INTO backup_log (filename, file_size, operator_id)
            VALUES (?, ?, ?)
        ");
                if (!$insertStmt->execute([$filename, $file_size, $operator_id])) {
                    $errorInfo = $insertStmt->errorInfo();
                    throw new Exception("数据库错误: {$errorInfo[2]}");
                }

                $_SESSION['success'] = "备份成功: $filename";
            } catch (Exception $e) {
                $_SESSION['error'] = $e->getMessage();
                error_log("[Backup] " . $e->getMessage());
            }
            header("Location: data_security.php");
            exit;
            break;

        case 'delete':
            $file = basename($_GET['file']);
            $file_path = $backup_dir . $file;

            try {
                // 删除文件
                if (!file_exists($file_path)) {
                    throw new Exception("文件不存在: $file");
                }
                if (!unlink($file_path)) {
                    throw new Exception("文件删除失败");
                }

                // 删除数据库记录
                $deleteStmt = $pdo->prepare("DELETE FROM backup_log WHERE filename = ?");
                $deleteStmt->execute([$file]);

                if ($deleteStmt->rowCount() === 0) {
                    throw new Exception("数据库记录不存在");
                }

                $_SESSION['success'] = "删除成功: $file";
            } catch (Exception $e) {
                $_SESSION['error'] = $e->getMessage();
            }
            header("Location: data_security.php");
            exit;
            break;
    }
    header("Location: data_security.php");
    exit;
}

// 获取备份文件列表
$backups = $pdo->query("
    SELECT 
        bl.*,
        u.username AS operator_name
    FROM backup_log bl
    LEFT JOIN system_user u ON bl.operator_id = u.user_id
    ORDER BY bl.backup_time DESC
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>数据安全管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 悬浮提示样式 */
        td[title]:hover::after {
            content: attr(title);
            position: absolute;
            background: #fff;
            border: 1px solid #ddd;
            padding: 5px;
            margin-top: 20px;
            z-index: 100;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>数据备份管理</h2>
        <?php
        // 在 <div class="container"> 内部添加
        if (isset($_SESSION['success'])) {
            echo '<div class="alert alert-success">' . $_SESSION['success'] . '</div>';
            unset($_SESSION['success']);
        }
        if (isset($_SESSION['error'])) {
            echo '<div class="alert alert-error">' . $_SESSION['error'] . '</div>';
            unset($_SESSION['error']);
        }
        ?>
        <div class="card">
            <div class="toolbar">
                <a href="data_security.php?action=backup"
                    class="btn-action"
                    onclick="return confirm('确认执行手动备份？')">
                    立即备份
                </a>
                <span>自动备份每日03:00执行（保留最近7天）</span>
            </div>

            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>备份文件</th>
                            <th>大小</th>
                            <th>备份时间</th>
                            <th>操作人</th>
                            <th>存储路径</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($backups)): ?>
                            <tr>
                                <td colspan="6" class="empty-notice">暂无备份记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($backups as $b): ?>
                                <tr>
                                    <td><?= htmlspecialchars($b['filename']) ?></td>
                                    <td><?= round($b['file_size'] / 1024) ?>KB</td>
                                    <td><?= date('Y-m-d H:i', strtotime($b['backup_time'])) ?></td>
                                    <td><?= htmlspecialchars($b['operator_name'] ?? '系统') ?></td>
                                    <td title="<?= htmlspecialchars($backup_dir . $b['filename']) ?>">
                                        <?php
                                        $full_path = $backup_dir . $b['filename'];
                                        $parts = preg_split('#[\\\/]#', $full_path);
                                        $parts = array_slice($parts, -3);
                                        echo htmlspecialchars(implode('/', $parts));
                                        ?>
                                    </td>
                                    <td>
                                        <?php if (!file_exists($backup_dir . $b['filename'])): ?>
                                            <span class="file-missing">文件丢失</span>
                                        <?php endif; ?>
                                        <a href="data_security.php?action=delete&file=<?= $b['filename'] ?>"
                                            class="btn-delete">删除</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>