<?php
session_start();
require '../config.php';

// 获取当前用户门店权限
$stmt = $pdo->prepare("
    SELECT s.store_id, s.store_name, s.warehouse_id
    FROM system_user u
    LEFT JOIN store s ON u.store_id = s.store_id
    WHERE u.user_id = ?
");

$stmt->execute([$_SESSION['user_id']]);

$current_store = $stmt->fetch();


// 总部管理员查看全部数据
$is_hq_admin = ($_SESSION['role'] === 'admin' && !$current_store['store_id']);

// 获取跨店数据
$cross_data = $pdo->query("
    SELECT
        s.store_id,
        s.store_name,
        COUNT(DISTINCT so.order_id) AS order_count,
        SUM(so.total_amount) AS total_sales,
        SUM(oi.quantity) AS item_count
    FROM store s
    LEFT JOIN sales_order so ON s.store_id = so.store_id
    LEFT JOIN order_item oi USING(order_id)
    " . ($is_hq_admin ? '' : "WHERE s.store_id = {$current_store['store_id']}") . "
    GROUP BY s.store_id
    ORDER BY s.store_name
")->fetchAll();

// 获取库存分布
$inventory_dist = $pdo->query("
    SELECT 
        p.product_id,
        p.sku,
        p.brand,
        p.model,
        s.store_name,
        SUM(i.quantity) AS stock
    FROM inventory i
    JOIN products p USING(product_id)
    JOIN store s ON i.warehouse_id = s.warehouse_id
    " . ($is_hq_admin ? '' : "WHERE s.store_id = {$current_store['store_id']}") . "
    GROUP BY p.product_id, s.store_id
    ORDER BY p.sku
")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>多门店管理</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>门店运营总览<?= $is_hq_admin ? '' : '（' . $current_store['store_name'] . '）' ?></h2>

        <?php if ($is_hq_admin): ?>
            <div class="card">
                <h3>门店销售对比</h3>
                <div class="chart-container">
                    <canvas id="salesChart"></canvas>
                </div>
            </div>
        <?php endif; ?>

        <div class="card">
            <h3>销售数据汇总</h3>
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>门店名称</th>
                            <th>订单数量</th>
                            <th>总销售额</th>
                            <th>商品数量</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($cross_data as $d): ?>
                            <tr>
                                <td><?= $d['store_name'] ?></td>
                                <td><?= $d['order_count'] ?></td>
                                <td>¥<?= number_format($d['total_sales'], 2) ?></td>
                                <td><?= $d['item_count'] ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <div class="card">
            <h3>跨店库存分布</h3>
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>商品SKU</th>
                            <th>品牌型号</th>
                            <th>所在门店</th>
                            <th>库存数量</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($inventory_dist as $item): ?>
                            <tr>
                                <td><?= $item['sku'] ?></td>
                                <td><?= $item['brand'] . ' ' . $item['model'] ?></td>
                                <td><?= $item['store_name'] ?></td>
                                <td><?= $item['stock'] ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <?php if ($is_hq_admin): ?>
        <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
        <script>
            // 销售对比图表
            const ctx = document.getElementById('salesChart').getContext('2d');
            new Chart(ctx, {
                type: 'bar',
                data: {
                    labels: <?= json_encode(array_column($cross_data, 'store_name')) ?>,
                    datasets: [{
                        label: '门店销售额',
                        data: <?= json_encode(array_column($cross_data, 'total_sales')) ?>,
                        backgroundColor: '#3498db'
                    }]
                },
                options: {
                    scales: {
                        y: {
                            beginAtZero: true,
                            ticks: {
                                callback: value => '¥' + value.toLocaleString()
                            }
                        }
                    }
                }
            });
        </script>
    <?php endif; ?>
</body>

</html>