<?php
session_start();
require '../config.php';

// 可用模块列表
$modules = ['商品', '采购', '销售', '财务', '报表'];

// 更新权限配置
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $role = $_POST['role'];
    $permissions = $_POST['permissions'] ?? [];

    try {
        $pdo->beginTransaction();

        // 清除旧权限
        $pdo->prepare("
            DELETE p FROM user_privileges p
            JOIN system_user u USING(user_id)
            WHERE u.role = ?
        ")->execute([$role]);

        // 插入新权限
        $stmt = $pdo->prepare("
            INSERT INTO user_privileges (user_id, module, permission_level)
            SELECT user_id, ?, ?
            FROM system_user
            WHERE role = ?
        ");

        foreach ($permissions as $module => $level) {
            $stmt->execute([$module, $level, $role]);
        }

        $pdo->commit();
        $_SESSION['success'] = "权限更新成功";
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "操作失败：" . $e->getMessage();
    }
    header("Location: role_permissions.php");
    exit;
}

// 获取当前权限配置（修复GROUP BY错误）
$permissions = $pdo->query("
    SELECT 
        u.role,
        p.module,
        MAX(p.permission_level) AS permission_level
    FROM user_privileges p
    JOIN system_user u USING(user_id)
    GROUP BY u.role, p.module
")->fetchAll(PDO::FETCH_GROUP | PDO::FETCH_UNIQUE);
?>
<!DOCTYPE html>
<html>

<head>
    <title>角色权限管理</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>角色权限配置</h2>

        <div class="card">
            <form method="POST">
                <div class="form-group">
                    <label>选择角色：</label>
                    <select name="role" required>
                        <option value="admin">管理员</option>
                        <option value="store_manager">店长</option>
                        <option value="sales">销售</option>
                        <option value="finance">财务</option>
                        <option value="logistics">物流</option>
                    </select>
                </div>

                <div class="permission-grid">
                    <?php foreach ($modules as $module): ?>
                        <div class="permission-item">
                            <h4><?= $module ?>权限</h4>
                            <select name="permissions[<?= $module ?>]" required>
                                <option value="无">无权限</option>
                                <option value="只读">只读</option>
                                <option value="编辑">编辑</option>
                                <option value="管理">管理</option>
                            </select>
                        </div>
                    <?php endforeach; ?>
                </div>

                <button type="submit" class="btn">保存配置</button>
            </form>
        </div>
    </div>
</body>

</html>