<?php
session_start();
require '../config.php';

// 删除用户
if (isset($_GET['delete'])) {
    $user_id = (int)$_GET['delete'];

    try {
        $pdo->beginTransaction();

        // 删除权限记录
        $pdo->prepare("DELETE FROM user_privileges WHERE user_id = ?")->execute([$user_id]);

        // 删除用户
        $pdo->prepare("DELETE FROM system_user WHERE user_id = ?")->execute([$user_id]);

        $pdo->commit();
        $_SESSION['success'] = "用户删除成功";
    } catch (PDOException $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "删除失败：" . $e->getMessage();
    }
    header("Location: user_management.php");
    exit;
}

// 获取所有用户
$users = $pdo->query("
    SELECT 
        u.user_id,
        u.username,
        u.role,
        u.last_login,
        s.store_name
    FROM system_user u
    LEFT JOIN store s ON u.store_id = s.store_id
    ORDER BY u.role, u.username
")->fetchAll();

// 获取所有门店
$stores = $pdo->query("SELECT store_id, store_name FROM store")->fetchAll();
?>
<!DOCTYPE html>
<html>

<head>
    <title>用户管理</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>系统用户管理</h2>

        <!-- 用户创建表单 -->
        <div class="card">
            <h3>新建用户</h3>
            <form method="POST" action="user_create.php">
                <div class="form-group">
                    <label>用户名</label>
                    <input type="text" name="username" required
                        pattern="[A-Za-z0-9_]{3,20}"
                        title="3-20位字母、数字或下划线">
                </div>

                <div class="form-group">
                    <label>密码</label>
                    <input type="password" name="password" required minlength="6">
                </div>

                <div class="form-group">
                    <label>角色</label>
                    <select name="role" id="roleSelect" required>
                        <option value="admin">管理员</option>
                        <option value="store_manager">店长</option>
                        <option value="sales">销售</option>
                        <option value="finance">财务</option>
                        <option value="logistics">物流</option>
                    </select>
                </div>

                <div class="form-group" id="storeField" style="display:none;">
                    <label>关联门店</label>
                    <select name="store_id" required>
                        <?php foreach ($stores as $store): ?>
                            <option value="<?= $store['store_id'] ?>"><?= $store['store_name'] ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <button type="submit" class="btn">创建用户</button>
            </form>
        </div>

        <!-- 用户列表 -->
        <div class="card">
            <h3>现有用户</h3>
            <table class="data-table">
                <thead>
                    <tr>
                        <th>用户名</th>
                        <th>角色</th>
                        <th>关联门店</th>
                        <th>最后登录</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($users as $user): ?>
                        <tr>
                            <td><?= $user['username'] ?></td>
                            <td><?= $user['role'] ?></td>
                            <td><?= $user['store_name'] ?? '--' ?></td>
                            <td><?= $user['last_login'] ? date('Y-m-d H:i', strtotime($user['last_login'])) : '从未登录' ?></td>
                            <td>
                                <a href="user_edit.php?id=<?= $user['user_id'] ?>" class="btn-edit">编辑</a>
                                <a href="user_management.php?delete=<?= $user['user_id'] ?>"
                                    onclick="return confirm('确认删除该用户？')"
                                    class="btn-delete">删除</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <script>
        // 修改角色监听逻辑
        document.getElementById('roleSelect').addEventListener('change', function() {
            const storeField = document.getElementById('storeField');
            const showStore = ['admin', 'store_manager'].includes(this.value);
            storeField.style.display = showStore ? 'block' : 'none';
            storeField.querySelector('select').required = showStore;
        });
    </script>
</body>

</html>